@@ -5,8 +5,8 @@ import java.rmi.RemoteException;
 
 public interface EagleManager extends Remote{
 
-	public void shutdown() throws RemoteException;
+   void shutdown() throws RemoteException;
 
-	public void reloadZones() throws RemoteException;
+   void reloadZones() throws RemoteException;
 
-}
\ No newline at end of file
+}
