@@ -12,21 +12,21 @@ import java.util.concurrent.RejectedExecutionException;
 
 public interface ExecutionController<Task extends TaskGroup> {
 
-	public void start() throws RejectedExecutionException;
-	
-	public void abort();
-	
-	public int getRemainingTaskCount();
-	
-	public void awaitExecution() throws InterruptedException;
-	
-	public void awaitExecution(long timeout) throws InterruptedException;
+   void start() throws RejectedExecutionException;
 
-	public boolean isStarted();
+   void abort();
 
-	public boolean isAborted();
+   int getRemainingTaskCount();
 
-	public boolean isFinished();
-	
-	public Task getTaskGroup();
+   void awaitExecution() throws InterruptedException;
+
+   void awaitExecution(long timeout) throws InterruptedException;
+
+   boolean isStarted();
+
+   boolean isAborted();
+
+   boolean isFinished();
+
+   Task getTaskGroup();
 }
