@@ -10,6 +10,6 @@ package se.unlogic.standardutils.validation;
 
 public interface StringFormatValidator {
 
-	public abstract boolean validateFormat(String value);
+   boolean validateFormat(String value);
 
 }
