@@ -11,5 +11,5 @@ import org.w3c.dom.Document;
 import se.unlogic.standardutils.validation.ValidationException;
 
 public interface BeanXMLPopulator<Type> {
-	public Type populate(Document doc) throws ValidationException;
+   Type populate(Document doc) throws ValidationException;
 }
