@@ -26,12 +26,13 @@ import org.apache.james.mime4j.storage.StorageOutputStream;
 import org.apache.james.mime4j.storage.StorageProvider;
 import org.apache.james.mime4j.storage.ThresholdStorageProvider;
 import org.apache.james.mime4j.util.MimeUtil;
+import org.jboss.logging.Logger;
 import org.jboss.resteasy.core.ProvidersContextRetainer;
 import org.jboss.resteasy.plugins.providers.multipart.i18n.Messages;
+import org.jboss.resteasy.resteasy_jaxrs.i18n.LogMessages;
 import org.jboss.resteasy.spi.HttpRequest;
 import org.jboss.resteasy.spi.ResteasyProviderFactory;
 import org.jboss.resteasy.util.CaseInsensitiveMap;
-import org.jboss.resteasy.resteasy_jaxrs.i18n.*;
 
 import javax.ws.rs.core.GenericType;
 import javax.ws.rs.core.HttpHeaders;
@@ -76,7 +77,6 @@ public class MultipartInputImpl implements MultipartInput, ProvidersContextRetai
    protected MediaType defaultPartContentType = MultipartConstants.TEXT_PLAIN_WITH_CHARSET_US_ASCII_TYPE;
    protected String defaultPartCharset = null;
    protected Providers savedProviders;
-
    // We hack MIME4j so that it always returns a BinaryBody so we don't have to deal with Readers and their charset conversions
    private static class BinaryOnlyMessageBuilder extends MessageBuilder
    {
@@ -194,14 +194,14 @@ public class MultipartInputImpl implements MultipartInput, ProvidersContextRetai
       this.contentType = contentType;
       this.workers = workers;
       HttpRequest httpRequest = ResteasyProviderFactory
-              .getContextData(HttpRequest.class);
+            .getContextData(HttpRequest.class);
       if (httpRequest != null)
       {
          String defaultContentType = (String) httpRequest
                  .getAttribute(InputPart.DEFAULT_CONTENT_TYPE_PROPERTY);
          if (defaultContentType != null)
             this.defaultPartContentType = MediaType
-                    .valueOf(defaultContentType);
+               .valueOf(defaultContentType);
          this.defaultPartCharset = (String) httpRequest.getAttribute(InputPart.DEFAULT_CHARSET_PROPERTY);
          if (defaultPartCharset != null)
          {
@@ -237,16 +237,16 @@ public class MultipartInputImpl implements MultipartInput, ProvidersContextRetai
    }
 
    protected InputStream addHeaderToHeadlessStream(InputStream is)
-           throws UnsupportedEncodingException
+         throws UnsupportedEncodingException
    {
       return new SequenceInputStream(createHeaderInputStream(), is);
    }
 
    protected InputStream createHeaderInputStream()
-           throws UnsupportedEncodingException
+         throws UnsupportedEncodingException
    {
       String header = HttpHeaders.CONTENT_TYPE + ": " + contentType
-              + "\r\n\r\n";
+            + "\r\n\r\n";
       return new ByteArrayInputStream(header.getBytes(StandardCharsets.UTF_8));
    }
 
@@ -317,7 +317,7 @@ public class MultipartInputImpl implements MultipartInput, ProvidersContextRetai
 
       @SuppressWarnings("unchecked")
       public <T> T getBody(Class<T> type, Type genericType)
-              throws IOException
+            throws IOException
       {
          if (MultipartInput.class.equals(type))
          {
@@ -410,40 +410,41 @@ public class MultipartInputImpl implements MultipartInput, ProvidersContextRetai
    public static void main(String[] args) throws Exception
    {
       String input = "URLSTR: file:/Users/billburke/jboss/resteasy-jaxrs/resteasy-jaxrs/src/test/test-data/data.txt\r\n"
-              + "--B98hgCmKsQ-B5AUFnm2FnDRCgHPDE3\r\n"
-              + "Content-Disposition: form-data; name=\"part1\"\r\n"
-              + "Content-Type: text/plain; charset=US-ASCII\r\n"
-              + "Content-Transfer-Encoding: 8bit\r\n"
-              + "\r\n"
-              + "This is Value 1\r\n"
-              + "--B98hgCmKsQ-B5AUFnm2FnDRCgHPDE3\r\n"
-              + "Content-Disposition: form-data; name=\"part2\"\r\n"
-              + "Content-Type: text/plain; charset=US-ASCII\r\n"
-              + "Content-Transfer-Encoding: 8bit\r\n"
-              + "\r\n"
-              + "This is Value 2\r\n"
-              + "--B98hgCmKsQ-B5AUFnm2FnDRCgHPDE3\r\n"
-              + "Content-Disposition: form-data; name=\"data.txt\"; filename=\"data.txt\"\r\n"
-              + "Content-Type: application/octet-stream; charset=ISO-8859-1\r\n"
-              + "Content-Transfer-Encoding: binary\r\n"
-              + "\r\n"
-              + "hello world\r\n" + "--B98hgCmKsQ-B5AUFnm2FnDRCgHPDE3--";
+            + "--B98hgCmKsQ-B5AUFnm2FnDRCgHPDE3\r\n"
+            + "Content-Disposition: form-data; name=\"part1\"\r\n"
+            + "Content-Type: text/plain; charset=US-ASCII\r\n"
+            + "Content-Transfer-Encoding: 8bit\r\n"
+            + "\r\n"
+            + "This is Value 1\r\n"
+            + "--B98hgCmKsQ-B5AUFnm2FnDRCgHPDE3\r\n"
+            + "Content-Disposition: form-data; name=\"part2\"\r\n"
+            + "Content-Type: text/plain; charset=US-ASCII\r\n"
+            + "Content-Transfer-Encoding: 8bit\r\n"
+            + "\r\n"
+            + "This is Value 2\r\n"
+            + "--B98hgCmKsQ-B5AUFnm2FnDRCgHPDE3\r\n"
+            + "Content-Disposition: form-data; name=\"data.txt\"; filename=\"data.txt\"\r\n"
+            + "Content-Type: application/octet-stream; charset=ISO-8859-1\r\n"
+            + "Content-Transfer-Encoding: binary\r\n"
+            + "\r\n"
+            + "hello world\r\n" + "--B98hgCmKsQ-B5AUFnm2FnDRCgHPDE3--";
       ByteArrayInputStream bais = new ByteArrayInputStream(input.getBytes());
       Map<String, String> parameters = new LinkedHashMap<String, String>();
       parameters.put("boundary", "B98hgCmKsQ-B5AUFnm2FnDRCgHPDE3");
       MediaType contentType = new MediaType("multipart", "form-data",
-              parameters);
+            parameters);
       MultipartInputImpl multipart = new MultipartInputImpl(contentType, null);
       multipart.parse(bais);
 
-      System.out.println(multipart.getPreamble());
-      System.out.println("**********");
+      Logger LOG = Logger.getLogger(MultipartInputImpl.class);
+      LOG.info(multipart.getPreamble());
+      LOG.info("**********");
       for (InputPart part : multipart.getParts())
       {
-         System.out.println("--");
-         System.out.println("\"" + part.getBodyAsString() + "\"");
+         LOG.info("--");
+         LOG.info("\"" + part.getBodyAsString() + "\"");
       }
-      System.out.println("done");
+      LOG.info("done");
 
    }
 
@@ -525,12 +526,12 @@ public class MultipartInputImpl implements MultipartInput, ProvidersContextRetai
 
       private final File directory;
 
-      public CustomTempFileStorageProvider()
+      CustomTempFileStorageProvider()
       {
          this(DEFAULT_PREFIX, null, null);
       }
 
-      public CustomTempFileStorageProvider(String prefix, String suffix, File directory)
+      CustomTempFileStorageProvider(String prefix, String suffix, File directory)
       {
          if (prefix == null || prefix.length() < 3)
             throw new IllegalArgumentException("invalid prefix");
@@ -556,7 +557,7 @@ public class MultipartInputImpl implements MultipartInput, ProvidersContextRetai
 
          private OutputStream out;
 
-         public TempFileStorageOutputStream(File file) throws IOException
+         TempFileStorageOutputStream(File file) throws IOException
          {
             this.file = file;
             this.out = new FileOutputStream(file);
@@ -590,7 +591,7 @@ public class MultipartInputImpl implements MultipartInput, ProvidersContextRetai
 
          private static final Set<File> filesToDelete = new HashSet<File>();
 
-         public TempFileStorage(File file)
+         TempFileStorage(File file)
          {
             this.file = file;
          }
