@@ -6,6 +6,7 @@ import org.apache.http.HttpEntity;
 import org.apache.http.HttpHost;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.HttpClient;
+import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpPost;
 import org.apache.http.client.methods.HttpRequestBase;
@@ -42,6 +43,8 @@ import java.lang.management.ManagementFactory;
 import java.util.List;
 import java.util.Map;
 
+
+
 /**
  * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
  * @version $Revision: 1 $
@@ -69,6 +72,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
    protected int responseBufferSize = 8192;
    protected HttpHost defaultProxy = null;
    protected boolean chunked = false;
+   protected boolean followRedirects = false;
 
    /**
     * For uploading File's over JAX-RS framework, this property, together with {@link #fileUploadMemoryUnit},
@@ -82,7 +86,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
    /**
     * Enumeration to represent memory units.
     */
-   public static enum MemoryUnit
+   public enum MemoryUnit
    {
       /**
        * Bytes
@@ -154,7 +158,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
     * attributes in it. It is hence recommended to override the HttpClient
     * <pre>execute(HttpUriRequest request, HttpContext context)</pre> method to perform a deep
     * copy of the context before executing the request.
-    * 
+    *
     * @param httpClient     The http client
     * @param httpContext    The context to be used for executing requests
     */
@@ -175,7 +179,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
     * Response stream is wrapped in a BufferedInputStream.  Default is 8192.  Value of 0 will not wrap it.
     * Value of -1 will use a SelfExpandingBufferedInputStream
     *
-    * @return
+    * @return response buffer size
     */
    public int getResponseBufferSize()
    {
@@ -186,7 +190,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
     * Response stream is wrapped in a BufferedInputStream.  Default is 8192.  Value of 0 will not wrap it.
     * Value of -1 will use a SelfExpandingBufferedInputStream
     *
-    * @param responseBufferSize
+    * @param responseBufferSize response buffer size
     */
    public void setResponseBufferSize(int responseBufferSize)
    {
@@ -195,7 +199,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
 
    /**
     * Based on memory unit
-    * @return
+    * @return threshold limit
     */
    public int getFileUploadInMemoryThresholdLimit()
    {
@@ -268,11 +272,11 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
 
    public HttpHost getDefaultProxy()
    {
-	   return (HttpHost) httpClient.getParams().getParameter(ConnRoutePNames.DEFAULT_PROXY);
+      return (HttpHost) httpClient.getParams().getParameter(ConnRoutePNames.DEFAULT_PROXY);
    }
 
    public static CaseInsensitiveMap<String> extractHeaders(
-           HttpResponse response)
+         HttpResponse response)
    {
       final CaseInsensitiveMap<String> headers = new CaseInsensitiveMap<String>();
 
@@ -330,6 +334,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
          protected void setInputStream(InputStream is)
          {
             stream = is;
+            resetEntity();
          }
 
          public InputStream getInputStream()
@@ -351,57 +356,85 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
             return stream;
          }
 
+         @Override
          public void releaseConnection() throws IOException
          {
-            // Apache Client 4 is stupid,  You have to get the InputStream and close it if there is an entity
-            // otherwise the connection is never released.  There is, of course, no close() method on response
-            // to make this easier.
-            try {
-               // Another stupid thing...TCK is testing a specific exception from stream.close()
-               // so, we let it propagate up.
-               if (stream != null)
+            releaseConnection(true);
+         }
+
+         @Override
+         public void releaseConnection(boolean consumeInputStream) throws IOException
+         {
+            if (consumeInputStream)
+            {
+               // Apache Client 4 is stupid,  You have to get the InputStream and close it if there is an entity
+               // otherwise the connection is never released.  There is, of course, no close() method on response
+               // to make this easier.
+               try
                {
-                  stream.close();
-               }
-               else
-               {
-                  InputStream is = getInputStream();
-                  if (is != null)
+                  // Another stupid thing...TCK is testing a specific exception from stream.close()
+                  // so, we let it propagate up.
+                  if (stream != null)
                   {
-                     is.close();
+                     stream.close();
                   }
+                  else
+                  {
+                     InputStream is = getInputStream();
+                     if (is != null)
+                     {
+                        is.close();
+                     }
+                  }
+               }
+               finally
+               {
+                  // just in case the input stream was entirely replaced and not wrapped, we need
+                  // to close the apache client input stream.
+                  if (hc4Stream != null)
+                  {
+                     try
+                     {
+                        hc4Stream.close();
+                     }
+                     catch (IOException ignored)
+                     {
+
+                     }
+                  }
+                  else
+                  {
+                     try
+                     {
+                        HttpEntity entity = res.getEntity();
+                        if (entity != null)
+                           entity.getContent().close();
+                     }
+                     catch (IOException ignored)
+                     {
+                     }
+
+                  }
+
                }
             }
-            finally {
-               // just in case the input stream was entirely replaced and not wrapped, we need
-               // to close the apache client input stream.
-               if (hc4Stream != null)
+            else if (res instanceof CloseableHttpResponse)
+            {
+               try
                {
-                  try {
-                     hc4Stream.close();
-                  }
-                  catch (IOException ignored) {
-
-                  }
+                  ((CloseableHttpResponse) res).close();
                }
-               else
+               catch (IOException e)
                {
-                  try
-                  {
-                     HttpEntity entity = res.getEntity();
-                     if (entity != null) entity.getContent().close();
-                  }
-                  catch (IOException ignored)
-                  {
-                  }
-
+                  LogMessages.LOGGER.warn(Messages.MESSAGES.couldNotCloseHttpResponse(), e);
                }
-
             }
-          }
+         }
+
       };
       response.setProperties(request.getMutableProperties());
       response.setStatus(res.getStatusLine().getStatusCode());
+      response.setReasonPhrase(res.getStatusLine().getReasonPhrase());
       response.setHeaders(extractHeaders(res));
       response.setClientConfiguration(request.getClientConfiguration());
       return response;
@@ -431,15 +464,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
       }
    }
 
-   protected boolean isRedirectRequired(final ClientInvocation request, final HttpRequestBase httpMethod)
-   {
-      if (httpMethod instanceof HttpGet && false) // todo  && request.followRedirects())
-      {
-         return true;
-      }
-      return false;
-   }
-
+   @SuppressWarnings("deprecation")
    protected HttpClient createDefaultHttpClient()
    {
       HttpParams params = new SyncBasicHttpParams();
@@ -464,13 +489,13 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
 
    protected void loadHttpMethod(final ClientInvocation request, HttpRequestBase httpMethod) throws Exception
    {
-      if (isRedirectRequired(request,httpMethod)) // todo  && request.followRedirects())
+      if (isFollowRedirects())
       {
          setRedirectRequired(request,httpMethod);
       }
       else
       {
-        setRedirectNotRequired(request,httpMethod);
+         setRedirectNotRequired(request,httpMethod);
       }
 
       if (request.getEntity() != null)
@@ -548,6 +573,16 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
    {
       this.chunked = chunked;
    }
+   
+   public boolean isFollowRedirects()
+   {
+      return followRedirects;
+   }
+
+   public void setFollowRedirects(boolean followRedirects)
+   {
+      this.followRedirects = followRedirects;
+   }
 
    /**
     * If passed httpMethod is of type HttpPost then obtain its entity. If the entity has an enclosing File then
@@ -625,7 +660,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
    private DeferredFileOutputStream writeRequestBodyToOutputStream(final ClientInvocation request) throws IOException
    {
       DeferredFileOutputStream memoryManagedOutStream =
-              new DeferredFileOutputStream(this.fileUploadInMemoryThresholdLimit * getMemoryUnitMultiplier(),
+            new DeferredFileOutputStream(this.fileUploadInMemoryThresholdLimit * getMemoryUnitMultiplier(),
                       getTempfilePrefix(), ".tmp", this.fileUploadTempFileDir);
       request.getDelegatingOutputStream().setDelegate(memoryManagedOutStream);
       request.writeRequestBody(request.getEntityStream());
@@ -695,7 +730,7 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
        * @param pFile -
        * @param pContentType -
        */
-      public FileExposingFileEntity(File pFile, String pContentType)
+      FileExposingFileEntity(File pFile, String pContentType)
       {
          super(pFile, pContentType);
       }
@@ -709,4 +744,4 @@ public class ApacheHttpClient4Engine implements ClientHttpEngine
       }
    }
 
-}
\ No newline at end of file
+}
