@@ -25,7 +25,6 @@ import javax.ws.rs.core.EntityTag;
 import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.MultivaluedMap;
 import javax.ws.rs.core.NewCookie;
-import javax.ws.rs.ext.MessageBodyReader;
 import javax.ws.rs.ext.Providers;
 import javax.ws.rs.ext.ReaderInterceptor;
 
@@ -43,8 +42,6 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 
-import static java.lang.String.format;
-
 /**
  * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
  * @version $Revision: 1 $
@@ -52,7 +49,7 @@ import static java.lang.String.format;
 @SuppressWarnings("unchecked")
 public class BaseClientResponse<T> extends ClientResponse<T>
 {
-   public static interface BaseClientResponseStreamFactory
+   public interface BaseClientResponseStreamFactory
    {
       InputStream getInputStream() throws IOException;
 
@@ -107,14 +104,18 @@ public class BaseClientResponse<T> extends ClientResponse<T>
             try
             {
                is = base.streamFactory.getInputStream();
-               byte[] bytes = ReadFromStream.readFromStream(1024, is);
-               is = new ByteArrayInputStream(bytes);
+               if (is != null)
+               {
+                  byte[] bytes = ReadFromStream.readFromStream(1024, is);
+                  is = new ByteArrayInputStream(bytes);
+               }
             }
             catch (IOException e)
             {
                // ignored
             }
          }
+
          final InputStream theIs = is;
          BaseClientResponse tmp = new BaseClientResponse(new BaseClientResponse.BaseClientResponseStreamFactory()
          {
@@ -331,10 +332,10 @@ public class BaseClientResponse<T> extends ClientResponse<T>
    {
       try
       {
-          if (this.streamFactory.getInputStream().markSupported())
-          {
-             this.streamFactory.getInputStream().reset();
-          }
+         if (this.streamFactory.getInputStream().markSupported())
+         {
+            this.streamFactory.getInputStream().reset();
+         }
       }
       catch (IOException e)
       {
@@ -371,7 +372,7 @@ public class BaseClientResponse<T> extends ClientResponse<T>
          return this.annotations;
       }
       return (this.returnType == type && this.genericReturnType == genericType) ? this.annotations
-              : null;
+            : null;
    }
 
    @Override
