@@ -37,7 +37,6 @@ import javax.ws.rs.core.MultivaluedMap;
 import javax.ws.rs.core.UriBuilder;
 
 import java.io.BufferedInputStream;
-import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
@@ -136,7 +135,7 @@ public class ApacheHttpClient4Executor implements ClientExecutor
     */
    public int getResponseBufferSize()
    {
-       return responseBufferSize;
+      return responseBufferSize;
    }
 
    /**
@@ -147,7 +146,7 @@ public class ApacheHttpClient4Executor implements ClientExecutor
     */
    public void setResponseBufferSize(int responseBufferSize)
    {
-       this.responseBufferSize = responseBufferSize;
+      this.responseBufferSize = responseBufferSize;
    }
 
    public HttpClient getHttpClient()
@@ -166,7 +165,7 @@ public class ApacheHttpClient4Executor implements ClientExecutor
    }
 
    public static CaseInsensitiveMap<String> extractHeaders(
-           HttpResponse response)
+         HttpResponse response)
    {
       final CaseInsensitiveMap<String> headers = new CaseInsensitiveMap<String>();
 
@@ -191,7 +190,7 @@ public class ApacheHttpClient4Executor implements ClientExecutor
    {
       BaseClientResponse response;
 
-      public ResponseStream(InputStream in, BaseClientResponse response)
+      ResponseStream(InputStream in, BaseClientResponse response)
       {
          super(in);
          // Keep a reference to the response object to prevent it being finalized prematurely
@@ -440,7 +439,7 @@ public class ApacheHttpClient4Executor implements ClientExecutor
    private DeferredFileOutputStream writeRequestBodyToOutputStream(final ClientRequest request) throws IOException
    {
       DeferredFileOutputStream memoryManagedOutStream =
-              new DeferredFileOutputStream(this.fileUploadInMemoryThresholdLimit * getMemoryUnitMultiplier(),
+            new DeferredFileOutputStream(this.fileUploadInMemoryThresholdLimit * getMemoryUnitMultiplier(),
                       getTempfilePrefix(), ".tmp", this.fileUploadTempFileDir);
       request.writeRequestBody(request.getHeadersAsObjects(), memoryManagedOutStream);
       memoryManagedOutStream.close();
@@ -591,7 +590,7 @@ public class ApacheHttpClient4Executor implements ClientExecutor
        * @param pFile        -
        * @param pContentType -
        */
-      public FileExposingFileEntity(File pFile, String pContentType)
+      FileExposingFileEntity(File pFile, String pContentType)
       {
          super(pFile, pContentType);
       }
@@ -608,7 +607,7 @@ public class ApacheHttpClient4Executor implements ClientExecutor
    /**
     * Enumeration to represent memory units.
     */
-   private static enum MemoryUnit
+   private enum MemoryUnit
    {
       /**
        * Bytes
@@ -629,4 +628,4 @@ public class ApacheHttpClient4Executor implements ClientExecutor
        */
       GB
    }
-}
\ No newline at end of file
+}
