@@ -5,12 +5,10 @@ import org.jboss.resteasy.core.interception.ContainerResponseContextImpl;
 import org.jboss.resteasy.core.interception.ResponseContainerRequestContext;
 import org.jboss.resteasy.core.interception.ServerWriterInterceptorContext;
 import org.jboss.resteasy.core.registry.SegmentNode;
-import org.jboss.resteasy.plugins.server.servlet.ResteasyContextParameters;
-import org.jboss.resteasy.resteasy_jaxrs.i18n.*;
+import org.jboss.resteasy.resteasy_jaxrs.i18n.LogMessages;
 import org.jboss.resteasy.specimpl.BuiltResponse;
 import org.jboss.resteasy.spi.HttpRequest;
 import org.jboss.resteasy.spi.HttpResponse;
-import org.jboss.resteasy.spi.ResteasyConfiguration;
 import org.jboss.resteasy.spi.ResteasyDeployment;
 import org.jboss.resteasy.spi.ResteasyProviderFactory;
 import org.jboss.resteasy.util.CommitHeaderOutputStream;
@@ -39,6 +37,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.function.Consumer;
 
 /**
  * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
@@ -46,104 +45,145 @@ import java.util.Map.Entry;
  */
 public class ServerResponseWriter
 {
-   public static void writeNomapResponse(BuiltResponse jaxrsResponse, final HttpRequest request, final HttpResponse response, final ResteasyProviderFactory providerFactory) throws IOException
+   @FunctionalInterface
+   public interface RunnableWithIOException {
+      void run() throws IOException;
+   }
+
+   public static void writeNomapResponse(BuiltResponse jaxrsResponse, final HttpRequest request, final HttpResponse response, 
+         final ResteasyProviderFactory providerFactory, Consumer<Throwable> onComplete) throws IOException
+   {
+      writeNomapResponse(jaxrsResponse, request, response, providerFactory, onComplete, true);
+   }
+
+   @Deprecated
+   public static void writeNomapResponse(BuiltResponse jaxrsResponse, final HttpRequest request, final HttpResponse response, 
+         final ResteasyProviderFactory providerFactory) throws IOException
+   {
+      writeNomapResponse(jaxrsResponse, request, response, providerFactory, t -> {}, true);
+   }
+
+   @Deprecated
+   public static void writeNomapResponse(BuiltResponse jaxrsResponse, final HttpRequest request, final HttpResponse response, 
+         final ResteasyProviderFactory providerFactory, boolean sendHeaders) throws IOException
+   {
+      writeNomapResponse(jaxrsResponse, request, response, providerFactory, t -> {}, sendHeaders);
+   }
+
+   public static void writeNomapResponse(BuiltResponse jaxrsResponse, final HttpRequest request, final HttpResponse response, 
+         final ResteasyProviderFactory providerFactory, Consumer<Throwable> onComplete, boolean sendHeaders) throws IOException
    {
       ResourceMethodInvoker method =(ResourceMethodInvoker) request.getAttribute(ResourceMethodInvoker.class.getName());
 
-      if (jaxrsResponse.getEntity() != null)
-      {
-        if (jaxrsResponse.getMediaType() == null)
-        {
-           setDefaultContentType(request, jaxrsResponse, providerFactory, method);
-        }
-        boolean addCharset = true;
-        ResteasyDeployment deployment = ResteasyProviderFactory.getContextData(ResteasyDeployment.class);
-        if (deployment != null)
-        {
-           addCharset = deployment.isAddCharset();
-        }
-        if (addCharset)
-        {
-           MediaType mt = null;
-           Object o = jaxrsResponse.getHeaders().getFirst(HttpHeaders.CONTENT_TYPE);
-           if (o instanceof MediaType)
-           {
-              mt = (MediaType) o;
-           }
-           else
-           {
-              mt = MediaType.valueOf(o.toString());
-           }
-           if (!mt.getParameters().containsKey(MediaType.CHARSET_PARAMETER))
-           {
-              if (MediaTypeHelper.isTextLike(mt))
-              {
-                 jaxrsResponse.getHeaders().putSingle(HttpHeaders.CONTENT_TYPE, mt.withCharset(StandardCharsets.UTF_8.toString()).toString());
-              }
-           }
-        }
-      }
-
-      executeFilters(jaxrsResponse, request, response, providerFactory, method);
-
-      //[RESTEASY-1627] check on response.getOutputStream() to avoid resteasy-netty4 trying building a chunked response body for HEAD requests 
-      if (jaxrsResponse.getEntity() == null || response.getOutputStream() == null)
-      {
-         response.setStatus(jaxrsResponse.getStatus());
-         commitHeaders(jaxrsResponse, response);
-         return;
-      }
-
-      Class type = jaxrsResponse.getEntityClass();
-      Object ent = jaxrsResponse.getEntity();
-      Type generic = jaxrsResponse.getGenericType();
-      Annotation[] annotations = jaxrsResponse.getAnnotations();
-      @SuppressWarnings(value = "unchecked")
-      final MediaType mt = jaxrsResponse.getMediaType();
-      MessageBodyWriter writer = providerFactory.getMessageBodyWriter(
-              type, generic, annotations, mt);
-      if (writer!=null)
-          LogMessages.LOGGER.debugf("MessageBodyWriter: %s", writer.getClass().getName());
-
-      if (writer == null)
-      {
-         throw new NoMessageBodyWriterFoundFailure(type, mt);
-      }
-
-      response.setStatus(jaxrsResponse.getStatus());
-      final BuiltResponse built = jaxrsResponse;
-      CommitHeaderOutputStream.CommitCallback callback = new CommitHeaderOutputStream.CommitCallback()
-      {
-         private boolean committed;
-
-         @Override
-         public void commit()
+      // do this even if we're not sending the headers, because this sets the content type in the response,
+      // which is used by marshalling, and NPEs otherwise
+      setResponseMediaType(jaxrsResponse, request, response, providerFactory, method);
+      
+      executeFilters(jaxrsResponse, request, response, providerFactory, method, onComplete, () -> {
+         //[RESTEASY-1627] check on response.getOutputStream() to avoid resteasy-netty4 trying building a chunked response body for HEAD requests 
+         if (jaxrsResponse.getEntity() == null || response.getOutputStream() == null)
          {
-            if (committed) return;
-            committed = true;
-            commitHeaders(built, response);
+            response.setStatus(jaxrsResponse.getStatus());
+            commitHeaders(jaxrsResponse, response);
+            return;
          }
-      };
-      OutputStream os = new CommitHeaderOutputStream(response.getOutputStream(), callback);
 
-      WriterInterceptor[] writerInterceptors = null;
-      if (method != null)
-      {
-         writerInterceptors = method.getWriterInterceptors();
-      }
-      else
-      {
-         writerInterceptors = providerFactory.getServerWriterInterceptorRegistry().postMatch(null, null);
-      }
+         Class type = jaxrsResponse.getEntityClass();
+         Object ent = jaxrsResponse.getEntity();
+         Type generic = jaxrsResponse.getGenericType();
+         Annotation[] annotations = jaxrsResponse.getAnnotations();
+         @SuppressWarnings(value = "unchecked")
+         final MediaType mt = jaxrsResponse.getMediaType();
+         MessageBodyWriter writer = providerFactory.getMessageBodyWriter(
+               type, generic, annotations, mt);
+         if (writer!=null)
+            LogMessages.LOGGER.debugf("MessageBodyWriter: %s", writer.getClass().getName());
 
-      AbstractWriterInterceptorContext writerContext =  new ServerWriterInterceptorContext(writerInterceptors,
-              providerFactory, ent, type, generic, annotations, mt,
-              jaxrsResponse.getMetadata(), os, request);
-      writerContext.proceed();
-      callback.commit(); // just in case the output stream is never used
+         if (writer == null)
+         {
+            throw new NoMessageBodyWriterFoundFailure(type, mt);
+         }
+
+         if(sendHeaders)
+            response.setStatus(jaxrsResponse.getStatus());
+         final BuiltResponse built = jaxrsResponse;
+         CommitHeaderOutputStream.CommitCallback callback = new CommitHeaderOutputStream.CommitCallback()
+         {
+            private boolean committed;
+
+            @Override
+            public void commit()
+            {
+               if (committed) return;
+               committed = true;
+               commitHeaders(built, response);
+            }
+         };
+         OutputStream os = sendHeaders ? new CommitHeaderOutputStream(response.getOutputStream(), callback) : response.getOutputStream();
+
+         WriterInterceptor[] writerInterceptors = null;
+         if (method != null)
+         {
+            writerInterceptors = method.getWriterInterceptors();
+         }
+         else
+         {
+            writerInterceptors = providerFactory.getServerWriterInterceptorRegistry().postMatch(null, null);
+         }
+
+         AbstractWriterInterceptorContext writerContext =  new ServerWriterInterceptorContext(writerInterceptors,
+               providerFactory, ent, type, generic, annotations, mt,
+               jaxrsResponse.getMetadata(), os, request);
+         writerContext.proceed();
+         if(sendHeaders) {
+            response.setOutputStream(writerContext.getOutputStream()); //propagate interceptor changes on the outputstream to the response
+            callback.commit(); // just in case the output stream is never used
+         }
+      });
    }
 
-   private static void executeFilters(BuiltResponse jaxrsResponse, HttpRequest request, HttpResponse response, ResteasyProviderFactory providerFactory, ResourceMethodInvoker method) throws IOException
+   public static void setResponseMediaType(BuiltResponse jaxrsResponse, HttpRequest request, HttpResponse response, ResteasyProviderFactory providerFactory, ResourceMethodInvoker method)
+   {
+      MediaType mt = getResponseMediaType(jaxrsResponse, request, response, providerFactory, method);
+      if (mt != null)
+      {
+         jaxrsResponse.getHeaders().putSingle(HttpHeaders.CONTENT_TYPE, mt.toString());
+      }
+   }
+      
+   public static MediaType getResponseMediaType(BuiltResponse jaxrsResponse, HttpRequest request, HttpResponse response, ResteasyProviderFactory providerFactory, ResourceMethodInvoker method)
+   {
+      MediaType mt = null;
+      if (jaxrsResponse.getEntity() != null)
+      {
+         if ((mt = jaxrsResponse.getMediaType()) == null)
+         {
+            mt = getDefaultContentType(request, jaxrsResponse, providerFactory, method);
+         }
+
+         boolean addCharset = true;
+         ResteasyDeployment deployment = ResteasyProviderFactory.getContextData(ResteasyDeployment.class);
+         if (deployment != null)
+         {
+            addCharset = deployment.isAddCharset();
+         }
+         if (addCharset)
+         {
+            if (!mt.getParameters().containsKey(MediaType.CHARSET_PARAMETER))
+            {
+               if (MediaTypeHelper.isTextLike(mt))
+               {
+                  mt = mt.withCharset(StandardCharsets.UTF_8.toString());
+               }
+            }
+         }
+      }
+      return mt;
+   }
+
+   private static void executeFilters(BuiltResponse jaxrsResponse, HttpRequest request, HttpResponse response, 
+         ResteasyProviderFactory providerFactory, 
+         ResourceMethodInvoker method, Consumer<Throwable> onComplete, RunnableWithIOException continuation) throws IOException
    {
       ContainerResponseFilter[] responseFilters = null;
 
@@ -159,15 +199,33 @@ public class ServerResponseWriter
       if (responseFilters != null)
       {
          ResponseContainerRequestContext requestContext = new ResponseContainerRequestContext(request);
-         ContainerResponseContextImpl responseContext = new ContainerResponseContextImpl(request, response, jaxrsResponse);
-         for (ContainerResponseFilter filter : responseFilters)
+         ContainerResponseContextImpl responseContext = new ContainerResponseContextImpl(request, response, jaxrsResponse, 
+            requestContext, responseFilters, onComplete, continuation);
+         // filter calls the continuation
+         responseContext.filter();
+      }
+      else
+      {
+         try 
          {
-            filter.filter(requestContext, responseContext);
+            continuation.run();
+            onComplete.accept(null);
+         }
+         catch(Throwable t)
+         {
+            onComplete.accept(t);
+            SynchronousDispatcher.rethrow(t);
          }
       }
    }
    
    protected static void setDefaultContentType(HttpRequest request, BuiltResponse jaxrsResponse, ResteasyProviderFactory providerFactory, ResourceMethodInvoker method)
+   {
+      MediaType chosen = getDefaultContentType(request, jaxrsResponse, providerFactory, method);
+      jaxrsResponse.getHeaders().putSingle(HttpHeaders.CONTENT_TYPE, chosen);
+   }
+   
+   protected static MediaType getDefaultContentType(HttpRequest request, BuiltResponse jaxrsResponse, ResteasyProviderFactory providerFactory, ResourceMethodInvoker method)   
    {
       // Note. If we get here before the request is executed, e.g., if a ContainerRequestFilter aborts,
       // chosen and method can be null.
@@ -322,7 +380,7 @@ public class ServerResponseWriter
          }
          chosen = new MediaType(chosen.getType(), chosen.getSubtype(), map);
       }
-      jaxrsResponse.getHeaders().putSingle(HttpHeaders.CONTENT_TYPE, chosen);
+      return chosen;
    }
    
    private static MediaType chooseFromM(MediaType currentChoice, List<SortableMediaType> M, boolean hasStarStar, boolean hasApplicationStar)
@@ -401,13 +459,18 @@ public class ServerResponseWriter
                   response.addNewCookie(cookie);
                   it.remove();
                }
+               else
+               {
+                  response.getOutputHeaders().add(javax.ws.rs.core.HttpHeaders.SET_COOKIE, next);
+                  it.remove();
+               }
             }
-            if (cookies.size() < 1)
-               jaxrsResponse.getMetadata().remove(HttpHeaderNames.SET_COOKIE);
+
+            jaxrsResponse.getMetadata().remove(HttpHeaderNames.SET_COOKIE);
          }
       }
       if (jaxrsResponse.getMetadata() != null
-              && jaxrsResponse.getMetadata().size() > 0)
+            && jaxrsResponse.getMetadata().size() > 0)
       {
          response.getOutputHeaders().putAll(jaxrsResponse.getMetadata());
       }
@@ -419,7 +482,7 @@ public class ServerResponseWriter
       double qs = 1;
       Class<?> writerType = null;
       
-      public SortableMediaType(String type, String subtype, Map<String, String> parameters, Class<?> writerType)
+      SortableMediaType(String type, String subtype, Map<String, String> parameters, Class<?> writerType)
       {
          super(type, subtype, parameters);
          this.writerType = writerType;
