@@ -2,6 +2,7 @@ package org.jboss.resteasy.core;
 
 import org.jboss.resteasy.client.core.ClientErrorInterceptor;
 import org.jboss.resteasy.client.exception.mapper.ClientExceptionMapper;
+import org.jboss.resteasy.core.interception.jaxrs.ClientRequestFilterRegistry;
 import org.jboss.resteasy.core.interception.ClientResponseFilterRegistry;
 import org.jboss.resteasy.core.interception.ContainerRequestFilterRegistry;
 import org.jboss.resteasy.core.interception.ContainerResponseFilterRegistry;
@@ -22,7 +23,6 @@ import org.jboss.resteasy.util.ThreadLocalStack;
 
 import javax.ws.rs.RuntimeType;
 import javax.ws.rs.client.ClientRequestFilter;
-import javax.ws.rs.client.ClientResponseFilter;
 import javax.ws.rs.container.DynamicFeature;
 import javax.ws.rs.core.Application;
 import javax.ws.rs.core.Configuration;
@@ -37,17 +37,18 @@ import javax.ws.rs.ext.ExceptionMapper;
 import javax.ws.rs.ext.MessageBodyReader;
 import javax.ws.rs.ext.MessageBodyWriter;
 import javax.ws.rs.ext.ParamConverter;
-import javax.ws.rs.ext.RuntimeDelegate;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Type;
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import org.jboss.resteasy.resteasy_jaxrs.i18n.*;
+import org.jboss.resteasy.resteasy_jaxrs.i18n.LogMessages;
+import org.jboss.resteasy.spi.AsyncResponseProvider;
+import org.jboss.resteasy.spi.AsyncStreamProvider;
 
 /**
- * Allow applications to push/pop provider factories onto the stack
+ * Allow applications to push/pop provider factories onto the stack.
  *
  * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
  * @version $Revision: 1 $
@@ -272,7 +273,7 @@ public class ThreadLocalResteasyProviderFactory extends ResteasyProviderFactory
    {
       MessageBodyReader<T> reader = getDelegate().getMessageBodyReader(type, genericType, annotations, mediaType);
       if (reader!=null)
-          LogMessages.LOGGER.debugf("MessageBodyReader: %s", reader.getClass().getName());
+         LogMessages.LOGGER.debugf("MessageBodyReader: %s", reader.getClass().getName());
       return reader;
    }
 
@@ -570,6 +571,18 @@ public class ThreadLocalResteasyProviderFactory extends ResteasyProviderFactory
       return getDelegate().toString(object, clazz, genericType, annotations);
    }
 
+   @Override
+   public ClientRequestFilterRegistry getClientRequestFilterRegistry()
+   {
+      return getDelegate().getClientRequestFilterRegistry();
+   }
+
+   /**
+    * This method retailed for backward compatibility for jaxrs-legacy code.
+    * Method, getClientRequestFilterRegistry, replaces it.
+    * @return interceptor registry
+    */
+   @Deprecated
    @Override
    public JaxrsInterceptorRegistry<ClientRequestFilter> getClientRequestFilters()
    {
@@ -611,7 +624,7 @@ public class ThreadLocalResteasyProviderFactory extends ResteasyProviderFactory
    {
       MessageBodyWriter<T> writer = getDelegate().getMessageBodyWriter(type, genericType, annotations, mediaType);
       if (writer!=null)
-          LogMessages.LOGGER.debugf("MessageBodyWriter: %s", writer.getClass().getName());
+         LogMessages.LOGGER.debugf("MessageBodyWriter: %s", writer.getClass().getName());
       return writer;
    }
 
@@ -627,6 +640,30 @@ public class ThreadLocalResteasyProviderFactory extends ResteasyProviderFactory
       return getDelegate().getExceptionMappers();
    }
 
+   @Override
+   public <T> AsyncResponseProvider<T> getAsyncResponseProvider(Class<T> type)
+   {
+      return getDelegate().getAsyncResponseProvider(type);
+   }
+   
+   @Override
+   public Map<Class<?>, AsyncResponseProvider> getAsyncResponseProviders()
+   {
+      return getDelegate().getAsyncResponseProviders();
+   }
+
+   @Override
+   public <T> AsyncStreamProvider<T> getAsyncStreamProvider(Class<T> type)
+   {
+      return getDelegate().getAsyncStreamProvider(type);
+   }
+   
+   @Override
+   public Map<Class<?>, AsyncStreamProvider> getAsyncStreamProviders()
+   {
+      return getDelegate().getAsyncStreamProviders();
+   }
+
    @Override
    public <T> HeaderDelegate<T> createHeaderDelegate(Class<T> tClass)
    {
@@ -638,7 +675,7 @@ public class ThreadLocalResteasyProviderFactory extends ResteasyProviderFactory
    {
       MessageBodyWriter<T> writer = getDelegate().getClientMessageBodyWriter(type, genericType, annotations, mediaType);
       if (writer!=null)
-          LogMessages.LOGGER.debugf("MessageBodyWriter: %s", writer.getClass().getName());
+         LogMessages.LOGGER.debugf("MessageBodyWriter: %s", writer.getClass().getName());
       return writer;
    }
 
@@ -647,7 +684,7 @@ public class ThreadLocalResteasyProviderFactory extends ResteasyProviderFactory
    {
       MessageBodyReader<T> reader = getDelegate().getClientMessageBodyReader(type, genericType, annotations, mediaType);
       if (reader!=null)
-          LogMessages.LOGGER.debugf("MessageBodyReader: %s", reader.getClass().getName());
+         LogMessages.LOGGER.debugf("MessageBodyReader: %s", reader.getClass().getName());
       return reader;
    }
 
@@ -656,7 +693,7 @@ public class ThreadLocalResteasyProviderFactory extends ResteasyProviderFactory
    {
       MessageBodyReader<T> reader = getDelegate().getServerMessageBodyReader(type, genericType, annotations, mediaType);
       if (reader!=null)
-          LogMessages.LOGGER.debugf("MessageBodyReader: %s", reader.getClass().getName());
+         LogMessages.LOGGER.debugf("MessageBodyReader: %s", reader.getClass().getName());
       return reader;
    }
 
@@ -665,7 +702,7 @@ public class ThreadLocalResteasyProviderFactory extends ResteasyProviderFactory
    {
       MessageBodyWriter<T> writer = getDelegate().getServerMessageBodyWriter(type, genericType, annotations, mediaType);
       if (writer!=null)
-          LogMessages.LOGGER.debugf("MessageBodyWriter: %s", writer.getClass().getName());
+         LogMessages.LOGGER.debugf("MessageBodyWriter: %s", writer.getClass().getName());
       return writer;
    }
 }
