@@ -21,10 +21,12 @@ import javax.ws.rs.NotSupportedException;
 import javax.ws.rs.Produces;
 import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.Response;
+import javax.ws.rs.core.Response.ResponseBuilder;
 
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -54,9 +56,8 @@ public class SegmentNode
    protected Map<String, SegmentNode> children = new HashMap<String, SegmentNode>();
    protected List<MethodExpression> targets = new ArrayList<MethodExpression>();
    protected boolean requestMatchingSet = false;
-   protected boolean looseStep2RequestMatching = false;
-   protected boolean widerRequestMatching = false;
-
+   protected boolean isJaxrs_2_0_RequestMatching = false;
+   
    public SegmentNode(String segment)
    {
       this.segment = segment;
@@ -88,10 +89,9 @@ public class SegmentNode
          ResteasyDeployment deployment = (ResteasyDeployment) contextDataMap.get(ResteasyDeployment.class);
          if (deployment != null)
          {
-            looseStep2RequestMatching = deployment.isLooseStep2RequestMatching();
-            widerRequestMatching = deployment.isWiderRequestMatching();
+            isJaxrs_2_0_RequestMatching = deployment.isJaxrs_2_0_RequestMatching();
             requestMatchingSet = true;
-   	     }
+         }
       }
       MethodExpression matchedExpression = null;
       List<Match> matches = new ArrayList<Match>();
@@ -143,22 +143,26 @@ public class SegmentNode
             }
             else
             {
-               if (looseStep2RequestMatching || widerRequestMatching)
+               if (isJaxrs_2_0_RequestMatching)
                {
-                  matches.add(new Match(expression, matcher));    
-               }
-               else if (matchedExpression == null)
-               {
-                  matchedExpression = expression;
-                  matches.add(new Match(expression, matcher));   
-               }
-               else if (matchedExpression.compareTo(expression) == 0)
-               {
-                  matches.add(new Match(expression, matcher));  
+                  if (matchedExpression == null)
+                  {
+                     matchedExpression = expression;
+                     matches.add(new Match(expression, matcher));   
+                  }
+                  else if (matchedExpression.compareTo(expression) == 0)
+                  {
+                     matches.add(new Match(expression, matcher));  
+                  }
+                  else
+                  {
+                     break;
+                  }
                }
                else
                {
-                  break;
+                  matches.add(new Match(expression, matcher));
+                  matchedExpression = expression;
                }
             }
          }
@@ -315,7 +319,7 @@ public class SegmentNode
          {
             String name = entry.getKey();
             if ("q".equals(name)
-                    || "qs".equals(name)) continue;
+               || "qs".equals(name)) continue;
             params.put(name, entry.getValue());
          }
          Annotation[] annotations = match.expression.invoker.getMethod().getAnnotations();
@@ -398,7 +402,6 @@ public class SegmentNode
       for (MediaType accept : requestAccepts) weightedAccepts.add(WeightedMediaType.parse(accept));
 
       List<Match> list = new ArrayList<Match>();
-
       boolean methodMatch = false;
       boolean consumeMatch = false;
 
@@ -428,7 +431,9 @@ public class SegmentNode
          {
             HashSet<String> allowed = new HashSet<String>();
             for (Match match : matches)
+            {
                allowed.addAll(((ResourceMethodInvoker) match.expression.getInvoker()).getHttpMethods());
+            }
 
             if (httpMethod.equalsIgnoreCase("HEAD") && allowed.contains("GET"))
             {
@@ -437,19 +442,45 @@ public class SegmentNode
 
             if (allowed.contains("GET")) allowed.add("HEAD");
             allowed.add("OPTIONS");
-            String allowHeaderValue = "";
+            StringBuilder allowHeaders = new StringBuilder("");
             boolean first = true;
             for (String allow : allowed)
             {
                if (first) first = false;
-               else allowHeaderValue += ", ";
-               allowHeaderValue += allow;
+               else allowHeaders.append(", ");
+               allowHeaders.append(allow);
             }
-
+            String allowHeaderValue = allowHeaders.toString();
+            
             if (httpMethod.equals("OPTIONS"))
             {
-               Response res = Response.ok(allowHeaderValue,  MediaType.TEXT_PLAIN_TYPE).header(HttpHeaderNames.ALLOW, allowHeaderValue).build();
-               throw new DefaultOptionsMethodException(Messages.MESSAGES.noResourceMethodFoundForOptions(), res);
+            
+               ResponseBuilder resBuilder =  Response.ok(allowHeaderValue.toString(),  MediaType.TEXT_PLAIN_TYPE).header(HttpHeaderNames.ALLOW, allowHeaderValue.toString());
+               
+               if (allowed.contains("PATCH"))
+               {  
+                  Set<MediaType> patchAccepts = new HashSet<MediaType>(8);
+                  for (Match match : matches)
+                  {
+                     if (((ResourceMethodInvoker) match.expression.getInvoker()).getHttpMethods().contains("PATCH"))
+                     {
+                        patchAccepts.addAll(Arrays.asList(((ResourceMethodInvoker) match.expression.getInvoker())
+                              .getConsumes()));
+                     }
+                  }
+                  StringBuilder acceptPatch = new StringBuilder("");
+                  first = true;
+                  for (MediaType mediaType : patchAccepts)
+                  {
+                     if (first)
+                        first = false;
+                     else
+                        acceptPatch.append(", ");
+                     acceptPatch.append(mediaType.toString());
+                  }
+                  resBuilder.header(HttpHeaderNames.ACCEPT_PATCH, acceptPatch.toString());
+               }
+               throw new DefaultOptionsMethodException(Messages.MESSAGES.noResourceMethodFoundForOptions(), resBuilder.build());
             }
             else
             {
