@@ -4,13 +4,17 @@ import java.lang.reflect.AccessibleObject;
 import java.lang.reflect.Method;
 import java.lang.reflect.Type;
 import java.net.URI;
+import java.net.URL;
 
+import javax.validation.ElementKind;
 import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.Response.Status;
 
 import org.jboss.logging.annotations.Message;
 import org.jboss.logging.annotations.Message.Format;
 import org.jboss.logging.annotations.MessageBundle;
+import org.jboss.resteasy.annotations.Stream;
+import org.jboss.resteasy.api.validation.ConstraintType;
 import org.jboss.resteasy.logging.Logger.LoggerType;
 import org.jboss.resteasy.util.WeightedLanguage;
 
@@ -27,6 +31,25 @@ public interface Messages
    Messages MESSAGES = org.jboss.logging.Messages.getBundle(Messages.class);
    int BASE = 3000;
    int BASE_ASYNC = 9500;
+   int BASE_VALIDATOR_11 = 8500;
+   
+   @Message(id = BASE_VALIDATOR_11 + 0, value = "ResteasyViolationException has invalid format: %s")
+   String exceptionHasInvalidFormat(String line);
+   
+   @Message(id = BASE_VALIDATOR_11 + 25, value = "Unable to parse ResteasyViolationException")
+   String unableToParseException();
+   
+   @Message(id = BASE_VALIDATOR_11 + 30, value = "unexpected path node type: %s")
+   String unexpectedPathNode(ElementKind kind);
+   
+   @Message(id = BASE_VALIDATOR_11 + 35, value = "unexpected path node type in method violation: %s")
+   String unexpectedPathNodeViolation(ElementKind kind);
+   
+   @Message(id = BASE_VALIDATOR_11 + 40, value = "unexpected violation type: %s")
+   String unexpectedViolationType(ConstraintType.Type type);
+   
+   @Message(id = BASE_VALIDATOR_11 + 45, value = "unknown object passed as constraint violation: %s")
+   String unknownObjectPassedAsConstraintViolation(Object o);
    
    @Message(id = BASE_ASYNC + 0, value = "-- already canceled")
    String alreadyCanceled();
@@ -69,7 +92,10 @@ public interface Messages
    
    @Message(id = BASE + 15, value = "application param was null")
    String applicationParamNull();
-   
+
+   @Message(id = BASE + 17, value = "ClassCastException: attempting to cast {0} to {1}", format=Format.MESSAGE_FORMAT)
+   String attemptingToCast(URL from, URL to);
+
    @Message(id = BASE + 20, value = "Bad arguments passed to %s")
    String badArguments(String methodName);
    
@@ -253,6 +279,18 @@ public interface Messages
    @Message(id = BASE + 320, value = "Failed processing arguments of %s")
    String failedProcessingArguments(String constructor);
    
+   @Message(id = BASE + 316, value = "Expected '\', '\n', or '\r', got %s")
+   String expectedExcapedCharacter(int n);
+      
+   @Message(id = BASE + 317, value = "Expected Stream.MODE.GENERAL or Stream.MODE.RAW, got %s")
+   String expectedStreamModeGeneralOrRaw(Stream.MODE mode);
+   
+   @Message(id = BASE + 318, value = "Expected @Stream or @Produces(\"text/event-stream\")")
+   String expectedStreamOrSseMediaType();
+   
+   @Message(id = BASE + 319, value = "Expected String or MediaType, got %s")
+   String expectedStringOrMediaType(Object o);   
+   
    @Message(id = BASE + 325, value = "Failed to construct %s")
    String failedToConstruct(String constructor);
 
@@ -708,4 +746,46 @@ public interface Messages
    
    @Message(id = BASE + 1070, value = "Wrong password for: %s")
    String wrongPassword(String user);
+   
+   @Message(id = BASE + 1080, value = "WebTarget is not set for creating SseEventSource")
+   String webTargetIsNotSetForEventSource();
+   @Message(id = BASE + 1081, value = "EventSource is not ready to open")
+   String eventSourceIsNotReadyForOpen();
+   @Message(id = BASE + 1082, value = "No suitable message body writer for class : %s")
+   String notFoundMBW(String className);
+   @Message(id = BASE + 1083, value = "Sever sent event feature requries HttpServlet30Dispatcher")
+   String asyncServletIsRequired();
+   @Message(id = BASE + 1084, value = "Failed to read SseEvent")
+   String readEventException();
+   @Message(id = BASE + 1085, value = "%s is not set for OutboundSseEvent builder")
+   String nullValueSetToCreateOutboundSseEvent(String field);
+   @Message(id = BASE + 1086, value = "Failed to write data to InBoundSseEvent")
+   String failedToWriteDataToInboudEvent();
+   @Message(id = BASE + 1087, value = "No suitable message body reader for class : %s")
+   String notFoundMBR(String className);
+   @Message(id = BASE + 1088, value = "Failed to read data from InboundSseEvent")
+   String failedToReadData();
+   @Message(id = BASE + 1089, value = "Failed to create SseEventOutput")
+   String failedToCreateSseEventOutput();
+
+   @Message(id = BASE + 1090, value = "Unable to instantiate AsyncResponseProvider")
+   String unableToInstantiateAsyncResponseProvider();
+   @Message(id = BASE + 1091, value = "Unable to instantiate AsyncStreamProvider")
+   String unableToInstantiateAsyncStreamProvider();
+   @Message(id = BASE + 1092, value = "SseEventSink is closed")
+   String sseEventSinkIsClosed();
+   
+   @Message(id = BASE + 1093, value = "SseBroadcaster is closed")
+   String sseBroadcasterIsClosed();
+   
+   @Message(id = BASE + 1094, value = "Unable to instantiate ContextInjector")
+   String unableToInstantiateContextInjector();
+
+   @Message(id = BASE + 1095, value = "Unable to instantiate AsyncClientResponseProvider")
+   String unableToInstantiateAsyncClientResponseProvider();
+   @Message(id = BASE + 1096, value = "Unable to instantiate AsyncClientStreamProvider")
+   String unableToInstantiateAsyncClientStreamProvider();
+   
+   @Message(id = BASE + 1097, value = "Registering a context resolver doesn't support lambdas")
+   String registeringContextResolverAsLambda();
 }
