@@ -24,39 +24,39 @@ import java.util.regex.Pattern;
  */
 public class ResteasyUriBuilder extends UriBuilder
 {
-	
-	private static final class URITemplateParametersMap extends HashMap<String, Object> {
 
-		private final Object[] parameterValues;
-		private int index;
-		
-		private URITemplateParametersMap(Object...parameterValues) {
-			this.parameterValues=parameterValues;
-		}
+   private static final class URITemplateParametersMap extends HashMap<String, Object> {
 
-		@Override
-		public Object get(Object key) {
-			Object object = null;
-			if ( !super.containsKey(key) && this.index != this.parameterValues.length) {
-				object = this.parameterValues[this.index++];
-				super.put((String) key, object);
-			}else{
-				object = super.get(key);
-			}
-			return object;
-		}
+      private final Object[] parameterValues;
+      private int index;
 
-		@Override
-		public boolean containsKey(Object key) {
-			boolean containsKey = super.containsKey(key);
-			if (!containsKey && this.index != this.parameterValues.length) {
-				super.put((String) key, this.parameterValues[this.index++]);
-				containsKey = true;
-			}
-			return containsKey;
-		}
+      private URITemplateParametersMap(Object...parameterValues) {
+         this.parameterValues=parameterValues;
+      }
 
-	}
+      @Override
+      public Object get(Object key) {
+         Object object = null;
+         if ( !super.containsKey(key) && this.index != this.parameterValues.length) {
+            object = this.parameterValues[this.index++];
+            super.put((String) key, object);
+         }else{
+            object = super.get(key);
+         }
+         return object;
+      }
+
+      @Override
+      public boolean containsKey(Object key) {
+         boolean containsKey = super.containsKey(key);
+         if (!containsKey && this.index != this.parameterValues.length) {
+            super.put((String) key, this.parameterValues[this.index++]);
+            containsKey = true;
+         }
+         return containsKey;
+      }
+
+   }
 
    private String host;
    private String scheme;
@@ -86,9 +86,10 @@ public class ResteasyUriBuilder extends UriBuilder
       return impl;
    }
 
-   public static final Pattern opaqueUri = Pattern.compile("^([^:/?#]+):([^/].*)");
-   public static final Pattern hierarchicalUri = Pattern.compile("^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\\?([^#]*))?(#(.*))?");
+   public static final Pattern opaqueUri = Pattern.compile("^([^:/?#{]+):([^/].*)");
+   public static final Pattern hierarchicalUri = Pattern.compile("^(([^:/?#{]+):)?(//([^/?#]*))?([^?#]*)(\\?([^#]*))?(#(.*))?");
    private static final Pattern hostPortPattern = Pattern.compile("([^/:]+):(\\d+)");
+   private static final Pattern squareHostBrackets = Pattern.compile( "(\\[(([0-9A-Fa-f]{0,4}:){2,7})([0-9A-Fa-f]{0,4})%?.*\\]):(\\d+)" );
 
    public static boolean compare(String s1, String s2)
    {
@@ -128,10 +129,10 @@ public class ResteasyUriBuilder extends UriBuilder
    }
 
    /**
-    * You may put path parameters anywhere within the uriTemplate except port
+    * You may put path parameters anywhere within the uriTemplate except port.
     *
-    * @param uriTemplate
-    * @return
+    * @param uriTemplate uri template
+    * @return uri builder
     */
    public static UriBuilder fromTemplate(String uriTemplate)
    {
@@ -141,10 +142,10 @@ public class ResteasyUriBuilder extends UriBuilder
    }
 
    /**
-    * You may put path parameters anywhere within the uriTemplate except port
+    * You may put path parameters anywhere within the uriTemplate except port.
     *
-    * @param uriTemplate
-    * @return
+    * @param uriTemplate uri template
+    * @return uri builder
     */
    public UriBuilder uriTemplate(String uriTemplate)
    {
@@ -189,20 +190,38 @@ public class ResteasyUriBuilder extends UriBuilder
             host = host.substring(at + 1);
             this. userInfo = user;
          }
+
          Matcher hostPortMatch = hostPortPattern.matcher(host);
          if (hostPortMatch.matches())
          {
             this.host = hostPortMatch.group(1);
             int val = 0;
-            try {
+            try
+            {
                this.port = Integer.parseInt(hostPortMatch.group(2));
-            }
-            catch (NumberFormatException e) {
+            } catch (NumberFormatException e)
+            {
                throw new IllegalArgumentException(Messages.MESSAGES.illegalUriTemplate(uriTemplate), e);
             }
-         }
-         else
+         } else
          {
+            if (host.startsWith("["))
+            {
+               // Must support an IPv6 hostname of format "[::1]" or [0:0:0:0:0:0:0:0]
+               // and IPv6 link-local format [fe80::1234%1] [ff08::9abc%interface10]
+               Matcher bracketsMatch = squareHostBrackets.matcher(host);
+               if (bracketsMatch.matches())
+               {
+                  host = bracketsMatch.group(1);
+                  try
+                  {
+                     this.port = Integer.parseInt(bracketsMatch.group(5));
+                  } catch (NumberFormatException e)
+                  {
+                     throw new IllegalArgumentException(Messages.MESSAGES.illegalUriTemplate(uriTemplate), e);
+                  }
+               }
+            }
             this.host = host;
          }
       }
@@ -210,7 +229,7 @@ public class ResteasyUriBuilder extends UriBuilder
       {
          String group = match.group(5);
          if (!scheme && !"".equals(group) && !group.startsWith("/") && group.indexOf(':') > -1 &&
-           group.indexOf('/') > -1 && group.indexOf(':') < group.indexOf('/'))
+            group.indexOf('/') > -1 && group.indexOf(':') < group.indexOf('/'))
             throw new IllegalArgumentException(Messages.MESSAGES.illegalUriTemplate(uriTemplate));
          if (!"".equals(group)) replacePath(group);
       }
@@ -500,10 +519,10 @@ public class ResteasyUriBuilder extends UriBuilder
    /**
     * Only replace path params in path of URI.  This changes state of URIBuilder.
     *
-    * @param name
-    * @param value
-    * @param isEncoded
-    * @return
+    * @param name parameter name
+    * @param value parameter value
+    * @param isEncoded encoded flag
+    * @return uri builder
     */
    public UriBuilder substitutePathParam(String name, Object value, boolean isEncoded)
    {
@@ -577,7 +596,7 @@ public class ResteasyUriBuilder extends UriBuilder
       }
       if (path != null)
       {
-    	 StringBuilder tmp = new StringBuilder();
+         StringBuilder tmp = new StringBuilder();
          replaceParameter(paramMap, fromEncodedMap, isTemplate, path, tmp, encodeSlash);
          String tmpPath = tmp.toString();
          if (userInfo != null || host != null)
@@ -601,10 +620,10 @@ public class ResteasyUriBuilder extends UriBuilder
 
    protected StringBuilder replacePathParameter(String name, String value, boolean isEncoded, String string, StringBuilder builder, boolean encodeSlash)
    {
-	  if (string.indexOf('{') == -1) 
-	  {
-		 return builder.append(string);
-	  }
+      if (string.indexOf('{') == -1)
+      {
+         return builder.append(string);
+      }
       Matcher matcher = createUriParamMatcher(string);
       int start = 0;
       while (matcher.find())
@@ -622,8 +641,8 @@ public class ResteasyUriBuilder extends UriBuilder
          {
             value = Encode.encodeNonCodes(value);
          }
-		 builder.append(value);
-		 start = matcher.end();
+         builder.append(value);
+         start = matcher.end();
       }
       builder.append(string, start, string.length());
       return builder;
@@ -631,35 +650,35 @@ public class ResteasyUriBuilder extends UriBuilder
 
    public static Matcher createUriParamMatcher(String string)
    {
-      Matcher matcher = PathHelper.URI_PARAM_PATTERN.matcher(PathHelper.replaceEnclosedCurlyBraces(string));
+      Matcher matcher = PathHelper.URI_PARAM_PATTERN.matcher(PathHelper.replaceEnclosedCurlyBracesCS(string));
       return matcher;
    }
 
    protected StringBuilder replaceParameter(Map<String, ? extends Object> paramMap, boolean fromEncodedMap, boolean isTemplate, String string, StringBuilder builder, boolean encodeSlash)
    {
-	  if (string.indexOf('{') == -1) 
-	  {
-		return builder.append(string);
-	  }
+      if (string.indexOf('{') == -1)
+      {
+         return builder.append(string);
+      }
       Matcher matcher = createUriParamMatcher(string);
       int start = 0;
       while (matcher.find())
       {
-    	 builder.append(string, start, matcher.start());
+         builder.append(string, start, matcher.start());
          String param = matcher.group(1);
-		 boolean containsValueForParam = paramMap.containsKey(param);
-		 if (!containsValueForParam)
-		 {
-			if (isTemplate) 
-			{
-				builder.append(matcher.group());
-				start = matcher.end();
-				continue;
-			}
+         boolean containsValueForParam = paramMap.containsKey(param);
+         if (!containsValueForParam)
+         {
+            if (isTemplate)
+            {
+               builder.append(matcher.group());
+               start = matcher.end();
+               continue;
+            }
             throw new IllegalArgumentException(Messages.MESSAGES.pathParameterNotProvided(param));
-		 }
-		 Object value = paramMap.get(param);
-		 String stringValue = value != null ? value.toString() : null;
+         }
+         Object value = paramMap.get(param);
+         String stringValue = value != null ? value.toString() : null;
          if (stringValue != null)
          {
             if (!fromEncodedMap)
@@ -672,8 +691,8 @@ public class ResteasyUriBuilder extends UriBuilder
                if (encodeSlash) stringValue = Encode.encodePathSegmentSaveEncodings(stringValue);
                else stringValue = Encode.encodePathSaveEncodings(stringValue);
             }
-			builder.append(stringValue);
-			start = matcher.end();
+            builder.append(stringValue);
+            start = matcher.end();
          }
          else
          {
@@ -686,41 +705,41 @@ public class ResteasyUriBuilder extends UriBuilder
 
    protected StringBuilder replaceQueryStringParameter(Map<String, ? extends Object> paramMap, boolean fromEncodedMap, boolean isTemplate, String string, StringBuilder builder)
    {
-	  if (string.indexOf('{') == -1) 
-	  {
-		return builder.append(string);
-	  }
+      if (string.indexOf('{') == -1)
+      {
+         return builder.append(string);
+      }
       Matcher matcher = createUriParamMatcher(string);
       int start = 0;
       while (matcher.find())
       {
-    	 builder.append(string, start, matcher.start());
+         builder.append(string, start, matcher.start());
          String param = matcher.group(1);
-		 boolean containsValueForParam = paramMap.containsKey(param);
-		 if (!containsValueForParam)
-		 {
-			if (isTemplate)
-			{
-				builder.append(matcher.group());
-				start = matcher.end();
-				continue;
-			}
-			throw new IllegalArgumentException(Messages.MESSAGES.pathParameterNotProvided(param));
-		 }
-		 Object value = paramMap.get(param);
-		 String stringValue = value != null ? value.toString() : null;
+         boolean containsValueForParam = paramMap.containsKey(param);
+         if (!containsValueForParam)
+         {
+            if (isTemplate)
+            {
+               builder.append(matcher.group());
+               start = matcher.end();
+               continue;
+            }
+            throw new IllegalArgumentException(Messages.MESSAGES.pathParameterNotProvided(param));
+         }
+         Object value = paramMap.get(param);
+         String stringValue = value != null ? value.toString() : null;
          if (stringValue != null)
          {
             if (!fromEncodedMap)
             {
-            	stringValue = Encode.encodeQueryParamAsIs(stringValue);
+               stringValue = Encode.encodeQueryParamAsIs(stringValue);
             }
             else
             {
-            	stringValue = Encode.encodeQueryParamSaveEncodings(stringValue);
+               stringValue = Encode.encodeQueryParamSaveEncodings(stringValue);
             }
-			builder.append(stringValue);
-			start = matcher.end();
+            builder.append(stringValue);
+            start = matcher.end();
          }
          else
          {
@@ -732,9 +751,9 @@ public class ResteasyUriBuilder extends UriBuilder
    }
 
    /**
-    * Return a unique order list of path params
+    * Return a unique order list of path params.
     *
-    * @return
+    * @return list of path parameters
     */
    public List<String> getPathParamNamesInDeclarationOrder()
    {
@@ -752,7 +771,7 @@ public class ResteasyUriBuilder extends UriBuilder
 
    private void addToPathParamList(List<String> params, HashSet<String> set, String string)
    {
-      Matcher matcher = PathHelper.URI_PARAM_PATTERN.matcher(PathHelper.replaceEnclosedCurlyBraces(string));
+      Matcher matcher = PathHelper.URI_PARAM_PATTERN.matcher(PathHelper.replaceEnclosedCurlyBracesCS(string));
       while (matcher.find())
       {
          String param = matcher.group(1);
@@ -821,18 +840,18 @@ public class ResteasyUriBuilder extends UriBuilder
       ArrayList<String> pathParams = new ArrayList<String>();
       boolean foundParam = false;
 
-      String pathWithoutEnclosedCurlyBraces = PathHelper.replaceEnclosedCurlyBraces(this.path);
+      CharSequence pathWithoutEnclosedCurlyBraces = PathHelper.replaceEnclosedCurlyBracesCS(this.path);
       Matcher matcher = PathHelper.URI_TEMPLATE_PATTERN.matcher(pathWithoutEnclosedCurlyBraces);
       StringBuilder newSegment = new StringBuilder();
       int from = 0;
       while (matcher.find())
       {
-    	 newSegment.append(pathWithoutEnclosedCurlyBraces, from, matcher.start());
+         newSegment.append(pathWithoutEnclosedCurlyBraces, from, matcher.start());
          foundParam = true;
          String group = matcher.group();
          pathParams.add(PathHelper.recoverEnclosedCurlyBraces(group));
-		 newSegment.append("_resteasy_uri_parameter");
-		 from = matcher.end();
+         newSegment.append("_resteasy_uri_parameter");
+         from = matcher.end();
       }
       newSegment.append(pathWithoutEnclosedCurlyBraces, from, pathWithoutEnclosedCurlyBraces.length());
       path = newSegment.toString();
@@ -887,9 +906,9 @@ public class ResteasyUriBuilder extends UriBuilder
          from = 0;
          while (matcher.find())
          {
-			newSegment.append(this.path, from, matcher.start());
-			newSegment.append(pathParams.get(i++));
-			from = matcher.end();
+            newSegment.append(this.path, from, matcher.start());
+            newSegment.append(pathParams.get(i++));
+            from = matcher.end();
          }
          newSegment.append(this.path, from, this.path.length());
          path = newSegment.toString();
@@ -905,7 +924,6 @@ public class ResteasyUriBuilder extends UriBuilder
     * <li> queryParam() supports URI template processing and this method must
     * always encode braces (for parameter substitution is not possible for
     * {@code @QueryParam} parameters).
-    * <p/>
     * <li> queryParam() supports "contextual URI encoding" (i.e., it does not
     * encode {@code %} characters that are followed by two hex characters).
     * The JavaDoc for {@code @QueryParam.value()} explicitly states that
