@@ -15,12 +15,10 @@ import org.jboss.resteasy.resteasy_jaxrs.i18n.LogMessages;
 import org.jboss.resteasy.resteasy_jaxrs.i18n.Messages;
 import org.jboss.resteasy.util.GetRestful;
 
-import javax.ws.rs.container.ResourceContext;
 import javax.ws.rs.core.Application;
 import javax.ws.rs.core.Configurable;
 import javax.ws.rs.core.Configuration;
 import javax.ws.rs.core.MediaType;
-import javax.ws.rs.ext.Provider;
 import javax.ws.rs.ext.Providers;
 import javax.ws.rs.core.Feature;
 import javax.ws.rs.core.FeatureContext;
@@ -29,6 +27,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.TreeMap;
 
 /**
  * This class is used to configure and initialize the core components of RESTEasy.
@@ -39,7 +38,7 @@ import java.util.Map;
 public class ResteasyDeployment
 {
    protected boolean widerRequestMatching;
-   protected boolean looseStep2RequestMatching = false;
+   protected boolean jaxrs_2_0_RequestMatching = false;
    protected boolean useContainerFormParams = false;
    protected boolean deploymentSensitiveFactoryEnabled = false;
    protected boolean asyncJobServiceEnabled = false;
@@ -50,6 +49,7 @@ public class ResteasyDeployment
    protected String asyncJobServiceBasePath = "/asynch/jobs";
    protected String applicationClass;
    protected String injectorFactoryClass;
+   protected InjectorFactory injectorFactory;
    protected Application application;
    protected boolean registerBuiltin = true;
    protected List<String> scannedResourceClasses = new ArrayList<String>();
@@ -78,9 +78,23 @@ public class ResteasyDeployment
    protected ResteasyProviderFactory providerFactory;
    protected ThreadLocalResteasyProviderFactory threadLocalProviderFactory;
    protected String paramMapping;
+   private Map<String, Object> properties = new TreeMap<String, Object>();
 
    @SuppressWarnings(value = "unchecked")
    public void start()
+   {
+      try
+      {
+         startInternal();
+      }
+      finally
+      {
+         ThreadLocalResteasyProviderFactory.pop();
+      }
+   }
+
+   @SuppressWarnings(value = {"unchecked", "deprecation"})
+   protected void startInternal()
    {
       // it is very important that each deployment create their own provider factory
       // this allows each WAR to have their own set of providers 
@@ -100,6 +114,14 @@ public class ResteasyDeployment
                threadLocalProviderFactory = new ThreadLocalResteasyProviderFactory(providerFactory);
                ResteasyProviderFactory.setInstance(threadLocalProviderFactory);
             }
+            else
+            {
+               ThreadLocalResteasyProviderFactory.push(providerFactory);
+            }
+         }
+         else
+         {
+            ThreadLocalResteasyProviderFactory.push(providerFactory);
          }
       }
       else
@@ -157,9 +179,8 @@ public class ResteasyDeployment
       
       try
       {
-         if (injectorFactoryClass != null)
+         if (injectorFactory == null && injectorFactoryClass != null)
          {
-            InjectorFactory injectorFactory;
             try
             {
                Class<?> clazz = Thread.currentThread().getContextClassLoader().loadClass(injectorFactoryClass);
@@ -173,10 +194,11 @@ public class ResteasyDeployment
             {
                throw new RuntimeException(Messages.MESSAGES.unableToInstantiateInjectorFactory(), e);
             }
-
+         }
+         if (injectorFactory != null)
+         {
             providerFactory.setInjectorFactory(injectorFactory);
          }
-
          // feed context data map with constructed objects
          // see ResteasyContextParameters.RESTEASY_CONTEXT_OBJECTS
          if (constructedDefaultContextObjects != null && constructedDefaultContextObjects.size() > 0)
@@ -518,7 +540,7 @@ public class ResteasyDeployment
    }
 
    /**
-    * @param config
+    * @param config application
     * @return whether application class registered anything. i.e. whether scanning metadata should be used or not
     */
    protected boolean processApplication(Application config)
@@ -578,19 +600,19 @@ public class ResteasyDeployment
       final Map<String, Object> properties = config.getProperties();
       if (properties != null && !properties.isEmpty())
       {
-          Feature appliationPropertiesRegistrationfeature = new Feature()
-          {
-			 @Override
-			 public boolean configure(FeatureContext featureContext)
-			 {
-				for (Map.Entry<String, Object> property : properties.entrySet())
-				{
-				   featureContext = featureContext.property(property.getKey(), property.getValue());
-				}
-				return true;
-			 }
-          };
-	      this.providers.add(0, appliationPropertiesRegistrationfeature);
+         Feature appliationPropertiesRegistrationfeature = new Feature()
+         {
+            @Override
+            public boolean configure(FeatureContext featureContext)
+            {
+               for (Map.Entry<String, Object> property : properties.entrySet())
+               {
+                  featureContext = featureContext.property(property.getKey(), property.getValue());
+               }
+               return true;
+            }
+         };
+         this.providers.add(0, appliationPropertiesRegistrationfeature);
       }
       return registered;
    }
@@ -974,16 +996,16 @@ public class ResteasyDeployment
       this.widerRequestMatching = widerRequestMatching;
    }
    
-   public boolean isLooseStep2RequestMatching()
+   public boolean isJaxrs_2_0_RequestMatching()
    {
-      return looseStep2RequestMatching;
+      return jaxrs_2_0_RequestMatching;
    }
-
-   public void setLooseStep2RequestMatching(boolean looseStep2RequestMatching)
+   
+   public void setJaxrs_2_0_RequestMatching(boolean jaxrs_2_0_RequestMatching)
    {
-      this.looseStep2RequestMatching = looseStep2RequestMatching;
+      this.jaxrs_2_0_RequestMatching = jaxrs_2_0_RequestMatching;
    }
-
+   
    public boolean isAddCharset()
    {
       return addCharset;
@@ -993,4 +1015,22 @@ public class ResteasyDeployment
    {
       this.addCharset = addCharset;
    }
+
+   public InjectorFactory getInjectorFactory()
+   {
+      return injectorFactory;
+   }
+
+   public void setInjectorFactory(InjectorFactory injectorFactory)
+   {
+      this.injectorFactory = injectorFactory;
+   }
+   
+   public Object getProperty(String key) {
+      return properties.get(key);
+   }
+
+   public void setProperty(String key, Object value) {
+      properties.put(key, value);
+   }
 }
