@@ -11,10 +11,10 @@ import java.lang.reflect.Method;
  * @deprecated The Resteasy interceptor facility introduced in release 2.x
  * is replaced by the JAX-RS 2.0 compliant interceptor facility in release 3.0.x.
  * 
- * @see jaxrs-api (https://jcp.org/en/jsr/detail?id=339)
+ * @see <a href="https://jcp.org/en/jsr/detail?id=339">jaxrs-api</a>
  */
 @Deprecated
 public interface AcceptedByMethod
 {
-   public boolean accept(Class declaring, Method method);
+   boolean accept(Class declaring, Method method);
 }
