@@ -1,9 +1,9 @@
 package org.jboss.resteasy.spi.metadata;
 
+import java.beans.Introspector;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.AccessibleObject;
 import java.lang.reflect.Method;
-import java.lang.reflect.Type;
 
 /**
  * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
@@ -19,6 +19,7 @@ public class SetterParameter extends Parameter
       super(declaredClass, setter.getParameterTypes()[0], setter.getGenericParameterTypes()[0]);
       this.setter = setter;
       this.annotatedMethod = annotatedMethod;
+      this.paramName = Introspector.decapitalize(setter.getName().substring(3));
    }
 
    public Method getSetter()
