@@ -1,5 +1,7 @@
 package org.jboss.resteasy.util;
 
+import org.jboss.resteasy.resteasy_jaxrs.i18n.Messages;
+
 import java.lang.reflect.Array;
 import java.lang.reflect.GenericArrayType;
 import java.lang.reflect.Method;
@@ -7,11 +9,10 @@ import java.lang.reflect.ParameterizedType;
 import java.lang.reflect.Type;
 import java.lang.reflect.TypeVariable;
 import java.lang.reflect.WildcardType;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.jboss.resteasy.resteasy_jaxrs.i18n.Messages;
-
 /**
  * Type conversions and generic type manipulations
  *
@@ -22,6 +23,9 @@ public class Types
 {
    /**
     * Is the genericType of a certain class?
+    * @param clazz class
+    * @param pType type
+    * @return boolean result
     */
    @SuppressWarnings(value = "unchecked")
    public static boolean isA(Class clazz, ParameterizedType pType)
@@ -31,6 +35,9 @@ public class Types
 
    /**
     * Gets the index-th type argument.
+    * @param pType type
+    * @param index index
+    * @return the type of argument at index position
     */
    public static Class getArgumentType(ParameterizedType pType, int index)
    {
@@ -97,11 +104,11 @@ public class Types
 
 
    /**
-    * See if the two methods are compatible, that is they have the same relative signature
+    * See if the two methods are compatible, that is they have the same relative signature.
     *
-    * @param method
-    * @param intfMethod
-    * @return
+    * @param method first method
+    * @param intfMethod second method
+    * @return boolean result
     */
    @SuppressWarnings(value = "unchecked")
    public static boolean isCompatible(Method method, Method intfMethod)
@@ -123,9 +130,9 @@ public class Types
    /**
     * Given a method and a root class, find the actual method declared in the root that implements the method.
     *
-    * @param clazz
-    * @param intfMethod
-    * @return
+    * @param clazz class
+    * @param intfMethod method
+    * @return method in the root class
     */
    @SuppressWarnings(value = "unchecked")
    public static Method getImplementingMethod(Class clazz, Method intfMethod)
@@ -195,6 +202,76 @@ public class Types
       return intfMethod;
    }
 
+   /**
+    * Find the by a method implementation implemented interface method.
+    *
+    * @param root The root class of the class hierarchy.
+    * @param iface The containing interface of the implemented method in the class hierarchy.
+    * @param implementation The method implementation.
+    * @return The implemented method.
+    */
+   public static Method getImplementedInterfaceMethod(final Class<?> root, final Class<?> iface, final Method implementation)
+   {
+      Method overriddenInterfaceMethod = findOverriddenMethod(root, iface, implementation);
+      if (overriddenInterfaceMethod != null) {
+         return overriddenInterfaceMethod;
+      }
+
+      for (Class<?> extended : iface.getInterfaces()) {
+         overriddenInterfaceMethod = getImplementedInterfaceMethod(root, extended, implementation);
+
+         if (overriddenInterfaceMethod != null) {
+            return overriddenInterfaceMethod;
+         }
+      }
+
+      return null;
+   }
+
+   /**
+    * Find the by a method implementation overridden superclass method.
+    *
+    * @param root The root class of the class hierarchy.
+    * @param superClass The containing class of the overridden method in the class hierarchy.
+    * @param implementation The method implementation.
+    * @return The overridden method.
+    */
+   public static Method findOverriddenMethod(final Class<?> root, final Class<?> superClass, final Method implementation)
+   {
+      // Check if the overridden method exists without generics
+      try
+      {
+         final Method method = superClass.getDeclaredMethod(implementation.getName(), implementation.getParameterTypes());
+         return method;
+      }
+      catch (NoSuchMethodException e)
+      {
+         // ignore
+      }
+
+      // Check if the overridden method exists with generics
+      final Map<TypeVariable<?>, Type> genericTypeMap = populateParameterizedMap(root, superClass);
+
+      for (Method superClassMethod : superClass.getDeclaredMethods())
+      {
+         if (superClassMethod.isSynthetic())
+         {
+            continue;
+         }
+         if (!implementation.getName().equals(superClassMethod.getName()) || implementation.getParameterCount() != superClassMethod.getParameterCount())
+         {
+            continue;
+         }
+
+         final Type[] actualMethodParameters = extractTypeVariables(genericTypeMap, superClassMethod.getGenericParameterTypes());
+         if (Arrays.equals(implementation.getGenericParameterTypes(), actualMethodParameters))
+         {
+            return superClassMethod;
+         }
+      }
+
+      return null;
+   }
 
    public static Class<?> getRawType(Type type)
    {
@@ -226,12 +303,12 @@ public class Types
       }
       else if (type instanceof WildcardType)
       {
-          WildcardType wildcardType = (WildcardType) type;
-          Type[] upperBounds = wildcardType.getUpperBounds();
-          if (upperBounds != null && upperBounds.length > 0)
-          {
-              return getRawType(upperBounds[0]);
-          }
+         WildcardType wildcardType = (WildcardType) type;
+         Type[] upperBounds = wildcardType.getUpperBounds();
+         if (upperBounds != null && upperBounds.length > 0)
+         {
+            return getRawType(upperBounds[0]);
+         }
       }
       throw new RuntimeException(Messages.MESSAGES.unableToDetermineBaseClass());
    }
@@ -261,9 +338,9 @@ public class Types
    }
 
    /**
-    * Returns the type argument from a parameterized type
+    * Returns the type argument from a parameterized type.
     *
-    * @param genericType
+    * @param genericType type
     * @return null if there is no type parameter
     */
    public static Class<?> getTypeArgument(Type genericType)
@@ -380,8 +457,8 @@ public class Types
     * Finds an actual value of a type variable. The method looks in a class hierarchy for a class defining the variable
     * and returns the value if present.
     *
-    * @param root
-    * @param typeVariable
+    * @param root root class
+    * @param typeVariable type variable
     * @return actual type of the type variable
     */
    public static Type resolveTypeVariable(Class<?> root, TypeVariable<?> typeVariable)
@@ -407,8 +484,8 @@ public class Types
    /**
     * Given a class and an interfaces, go through the class hierarchy to find the interface and return its type arguments.
     *
-    * @param classToSearch
-    * @param interfaceToFind
+    * @param classToSearch class
+    * @param interfaceToFind interface to find
     * @return type arguments of the interface
     */
    public static Type[] getActualTypeArgumentsOfAnInterface(Class<?> classToSearch, Class<?> interfaceToFind)
@@ -424,9 +501,9 @@ public class Types
     * Search for the given interface or class within the root's class/interface hierarchy.
     * If the searched for class/interface is a generic return an array of real types that fill it out.
     *
-    * @param root
-    * @param searchedFor
-    * @return
+    * @param root root class
+    * @param searchedFor searched class
+    * @return for generic class/interface returns array of real types
     */
    public static Type[] findParameterizedTypes(Class<?> root, Class<?> searchedFor)
    {
@@ -441,7 +518,7 @@ public class Types
    {
       if (Object.class.equals(root)) return null;
 
-      Map<String, Type> typeVarMap = populateParameterizedMap(root, rootType);
+      Map<TypeVariable<?>, Type> typeVarMap = populateParameterizedMap(root, rootType);
 
       Class<?> superclass = root.getSuperclass();
       Type genericSuper = root.getGenericSuperclass();
@@ -472,24 +549,54 @@ public class Types
       return null;
    }
 
-   private static Map<String, Type> populateParameterizedMap(Class<?> root, ParameterizedType rootType)
+   private static Map<TypeVariable<?>, Type> populateParameterizedMap(Class<?> root, ParameterizedType rootType)
    {
-      Map<String, Type> typeVarMap = new HashMap<String, Type>();
+      Map<TypeVariable<?>, Type> typeVarMap = new HashMap<>();
       if (rootType != null)
       {
          TypeVariable<? extends Class<?>>[] vars = root.getTypeParameters();
          for (int i = 0; i < vars.length; i++)
          {
-            typeVarMap.put(vars[i].getName(), rootType.getActualTypeArguments()[i]);
+            typeVarMap.put(vars[i], rootType.getActualTypeArguments()[i]);
          }
       }
       return typeVarMap;
    }
 
+   /**
+    * Create a mapping for generic types to actual types between two classes / interfaces of a type hierarchy.
+    *
+    * @param root The root class / interface of the type hierarchy.
+    * @param superClass A superclass / interface of the type hierarchy.
+    * @return The Mapping for generic types to actual types.
+    */
+   public static Map<TypeVariable<?>, Type> populateParameterizedMap(final Class<?> root, final Class<?> superClass)
+   {
+      final Type[] types = Types.findParameterizedTypes(root, superClass);
+      final TypeVariable<? extends Class<?>>[] typeParameters = superClass.getTypeParameters();
+
+      final Map<TypeVariable<?>, Type> genericTypeMap = new HashMap<>();
+      if (typeParameters != null && types != null)
+      {
+         int i = 0;
+         while (i < types.length)
+         {
+            genericTypeMap.put(typeParameters[i], types[i]);
+            i++;
+         }
+         while (i < typeParameters.length)
+         {
+            genericTypeMap.put(typeParameters[i], typeParameters[i].getGenericDeclaration());
+            i++;
+         }
+      }
+
+      return genericTypeMap;
+   }
 
    public static Type[] findInterfaceParameterizedTypes(Class<?> root, ParameterizedType rootType, Class<?> searchedForInterface)
    {
-      Map<String, Type> typeVarMap = populateParameterizedMap(root, rootType);
+      Map<TypeVariable<?>, Type> typeVarMap = populateParameterizedMap(root, rootType);
 
       for (int i = 0; i < root.getInterfaces().length; i++)
       {
@@ -518,7 +625,7 @@ public class Types
       return recurseSuperclassForInterface(searchedForInterface, typeVarMap, genericSuper, superclass);
    }
 
-   private static Type[] recurseSuperclassForInterface(Class<?> searchedForInterface, Map<String, Type> typeVarMap, Type genericSub, Class<?> sub)
+   private static Type[] recurseSuperclassForInterface(Class<?> searchedForInterface, Map<TypeVariable<?>, Type> typeVarMap, Type genericSub, Class<?> sub)
    {
       if (genericSub instanceof ParameterizedType)
       {
@@ -540,32 +647,42 @@ public class Types
       return null;
    }
 
-   private static Type[] extractTypeVariables(Map<String, Type> typeVarMap, Type[] types)
+   /**
+    * Resolve generic types to actual types.
+    *
+    * @param typeVarMap The mapping for generic types to actual types.
+    * @param types The types to resolve.
+    * @return An array of resolved method parameter types in declaration order.
+    */
+   private static Type[] extractTypeVariables(final Map<TypeVariable<?>, Type> typeVarMap, final Type[] types)
    {
-      for (int j = 0; j < types.length; j++)
+      final Type[] resolvedMethodParameterTypes = new Type[types.length];
+
+      for (int i = 0; i < types.length; i++)
       {
-         if (types[j] instanceof TypeVariable)
+         final Type methodParameterType = types[i];
+
+         if (methodParameterType instanceof TypeVariable<?>)
          {
-            TypeVariable tv = (TypeVariable) types[j];
-            types[j] = typeVarMap.get(tv.getName());
+            resolvedMethodParameterTypes[i] = typeVarMap.get(methodParameterType);
          }
          else
          {
-            types[j] = types[j];
+            resolvedMethodParameterTypes[i] = methodParameterType;
          }
       }
-      return types;
+
+      return resolvedMethodParameterTypes;
    }
 
-   private static Type[] extractTypes(Map<String, Type> typeVarMap, Type genericSub)
+   private static Type[] extractTypes(Map<TypeVariable<?>, Type> typeVarMap, Type genericSub)
    {
       if (genericSub instanceof ParameterizedType)
       {
          ParameterizedType param = (ParameterizedType) genericSub;
          Type[] types = param.getActualTypeArguments();
-         Type[] returnTypes = new Type[types.length];
-         System.arraycopy(types, 0, returnTypes, 0, types.length);
-         extractTypeVariables(typeVarMap, returnTypes);
+
+         Type[] returnTypes = extractTypeVariables(typeVarMap, types);
          return returnTypes;
       }
       else
