@@ -2,7 +2,12 @@ package org.jboss.resteasy.plugins.spring;
 
 import org.jboss.resteasy.core.Dispatcher;
 import org.jboss.resteasy.plugins.spring.i18n.Messages;
-import org.jboss.resteasy.spi.*;
+import org.jboss.resteasy.spi.HttpRequest;
+import org.jboss.resteasy.spi.HttpResponse;
+import org.jboss.resteasy.spi.PropertyInjector;
+import org.jboss.resteasy.spi.Registry;
+import org.jboss.resteasy.spi.ResteasyDeployment;
+import org.jboss.resteasy.spi.ResteasyProviderFactory;
 import org.jboss.resteasy.util.GetRestful;
 import org.springframework.aop.support.AopUtils;
 import org.springframework.beans.BeansException;
@@ -12,7 +17,11 @@ import org.springframework.beans.factory.FactoryBean;
 import org.springframework.beans.factory.NoSuchBeanDefinitionException;
 import org.springframework.beans.factory.annotation.AnnotatedBeanDefinition;
 import org.springframework.beans.factory.annotation.Required;
-import org.springframework.beans.factory.config.*;
+import org.springframework.beans.factory.config.BeanDefinition;
+import org.springframework.beans.factory.config.BeanFactoryPostProcessor;
+import org.springframework.beans.factory.config.BeanPostProcessor;
+import org.springframework.beans.factory.config.BeanReference;
+import org.springframework.beans.factory.config.ConfigurableListableBeanFactory;
 import org.springframework.beans.factory.support.RootBeanDefinition;
 import org.springframework.context.ApplicationContext;
 import org.springframework.context.ApplicationEvent;
@@ -26,7 +35,12 @@ import javax.ws.rs.ext.MessageBodyWriter;
 import javax.ws.rs.ext.Provider;
 
 import java.lang.reflect.Method;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
 
 /**
  * <p>
@@ -37,7 +51,6 @@ import java.util.*;
  * It also sets up Registry and ResteasyProviderFactory to be autowirable via @Autowire
  * in Controllers/service layers.
  * </p>
- * <p/>
  * <p>
  * There's quite a bit of spring integration functionality under the covers:
  * </p>
@@ -45,10 +58,7 @@ import java.util.*;
  * <li>@Providers, such as RESTEasy interceptors and String converters have to
  * be registered in RESTEasy before resources and registers. That gets a bit
  * tricky, so depends-on functionality is used as well</li>
- * <p/>
- * <li>
  * </ol>
- * <p/>
  *
  * @author <a href="mailto:sduskis@gmail.com">Solomon Duskis</a>
  * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
@@ -79,35 +89,31 @@ public class SpringBeanProcessor implements BeanFactoryPostProcessor, SmartAppli
       }
 
       public Object postProcessBeforeInitialization(Object bean, String beanName)
-              throws BeansException
+            throws BeansException
       {
          return bean;
       }
 
       /**
        * This method is invoked after postProcessBeanFactory.
-       * <p/>
+       * <p>
        * this method is invoked when ever a new bean is created. This will
        * perform the following:
-       * <p/>
        * <ol>
-       * <p/>
        * <li>RESTEasy injection of singleton @Providers, as well as @Provider
        * registration</li>
-       * <p/>
        * <li>either singleton or request/prototype RESTeasy injection... but not
        * registration. The RESTEasy registration happens in the
        * onApplicationEvent() below, which happens at the end of the Spring
        * life-cycle</li>
-       * <p/>
        * <li>merges the {@link ResteasyDeployment} bean with the user deployment</li>
-       * <p/>
        * </ol>
-       *
-       * @see SpringBeanProcessor.postProcessBeanFactory
+       * @param bean bean
+       * @param beanName bean name
+       * @see SpringBeanProcessor#postProcessBeanFactory(ConfigurableListableBeanFactory)
        */
       public Object postProcessAfterInitialization(Object bean, String beanName)
-              throws BeansException
+            throws BeansException
       {
          if (providerNames.contains(beanName))
          {
@@ -244,15 +250,16 @@ public class SpringBeanProcessor implements BeanFactoryPostProcessor, SmartAppli
     * registers the RESTEasy Registry, ProviderFactry, and Dispatcher for @Autowire
     * injection.
     * </p>
-    * <p/>
     * <p>
     * Beyond tracking, this will ensure that non-MessageBody(Reader|Writer) @Providers
     * are created by Spring before any resources by having the resources
     * "depends-on" the @Providers.
     * </p>
+    *
+    * @param beanFactory bean factory
     */
    public void postProcessBeanFactory(ConfigurableListableBeanFactory beanFactory)
-           throws BeansException
+         throws BeansException
    {
       beanFactory.registerResolvableDependency(Registry.class, getRegistry());
       beanFactory.registerResolvableDependency(ResteasyProviderFactory.class, getProviderFactory());
@@ -268,7 +275,7 @@ public class SpringBeanProcessor implements BeanFactoryPostProcessor, SmartAppli
          BeanDefinition beanDef = beanFactory.getBeanDefinition(name);
          if ( (beanDef.getBeanClassName() != null || beanDef.getFactoryBeanName() != null)
                  && !beanDef.isAbstract())
-             processBean(beanFactory, dependsOnBeans, name, beanDef);
+            processBean(beanFactory, dependsOnBeans, name, beanDef);
       }
 
       dependsOnBeans.addAll(registrations);
@@ -336,11 +343,11 @@ public class SpringBeanProcessor implements BeanFactoryPostProcessor, SmartAppli
       }
       if(value.getClass() == String.class)
       {
-          return (String) value;
+         return (String) value;
       }
       if(value instanceof BeanReference)
       {
-          return ((BeanReference)value).getBeanName();
+         return ((BeanReference)value).getBeanName();
       }
       throw new IllegalStateException(Messages.MESSAGES.resteasyRegistrationReferences());
    }
@@ -348,9 +355,9 @@ public class SpringBeanProcessor implements BeanFactoryPostProcessor, SmartAppli
    /**
     * merge two arrays.
     *
-    * @param dependsOn
-    * @param dependsOnProviders
-    * @return
+    * @param dependsOn first array
+    * @param dependsOnProviders second array
+    * @return merged array
     */
    private static String[] concat(String[] dependsOn, String[] dependsOnProviders)
    {
@@ -368,14 +375,14 @@ public class SpringBeanProcessor implements BeanFactoryPostProcessor, SmartAppli
    }
 
    /**
-    * Get the bean class, and take @Configuration @Beans into consideration
+    * Get the bean class, and take @Configuration @Beans into consideration.
     *
-    * @param beanDef
-    * @param beanFactory
-    * @return
+    * @param beanDef {@link BeanDefinition}
+    * @param beanFactory bean factory
+    * @return bean class
     */
    private static Class<?> getBeanClass(String name, BeanDefinition beanDef,
-                                        ConfigurableListableBeanFactory beanFactory)
+                              ConfigurableListableBeanFactory beanFactory)
    {
       if (beanDef instanceof RootBeanDefinition)
       {
@@ -423,13 +430,13 @@ public class SpringBeanProcessor implements BeanFactoryPostProcessor, SmartAppli
             }
          }
 
-          final Class<?> beanClass = getBeanClass(factoryClassName);
-          final Method[] methods = ReflectionUtils.getAllDeclaredMethods(beanClass);
-          for (Method method : methods) {
-              if (method.getName().equals(factoryMethodName)) {
-                  return method.getReturnType();
-              }
-          }
+         final Class<?> beanClass = getBeanClass(factoryClassName);
+         final Method[] methods = ReflectionUtils.getAllDeclaredMethods(beanClass);
+         for (Method method : methods) {
+            if (method.getName().equals(factoryMethodName)) {
+               return method.getReturnType();
+            }
+         }
 
          /*
             https://github.com/resteasy/Resteasy/issues/585
@@ -440,29 +447,29 @@ public class SpringBeanProcessor implements BeanFactoryPostProcessor, SmartAppli
             Case in which this tends to happen:
 
             1. A bean (Bean A) exists which provides factoryMethods for retrieving 1 or more other beans (Bean B, Bean C, ...)
-                example: <bean id="processEngine" class="org.activiti.spring.ProcessEngineFactoryBean"/>
+            example: <bean id="processEngine" class="org.activiti.spring.ProcessEngineFactoryBean"/>
             2. Bean B is retrieved by telling Spring that the Factory-Bean is Bean A and that there is a method X to retrieve Bean B.
-                example: <bean id="repositoryService" factory-bean="processEngine" factory-method="getRepositoryService"/>
+            example: <bean id="repositoryService" factory-bean="processEngine" factory-method="getRepositoryService"/>
             3. When resteasy has to inject Bean B it tries to lookup method X on Bean A instead of Bean B using the above code.
 
             As a fix for this, we retrieve the return type for Bean A from the FactoryBean, which later on can be used to retrieve the other beans.
 
-         */
-          if (FactoryBean.class.isAssignableFrom(beanClass)) {
-              String defaultFactoryMethod = "getObject";
-              Class<?> returnType = null;
-              for (Method method : methods) {
-                  if (method.getName().equals(defaultFactoryMethod)) {
-                      returnType = method.getReturnType();
-                      if (returnType != Object.class) {
-                          break;
-                      }
+       */
+         if (FactoryBean.class.isAssignableFrom(beanClass)) {
+            String defaultFactoryMethod = "getObject";
+            Class<?> returnType = null;
+            for (Method method : methods) {
+               if (method.getName().equals(defaultFactoryMethod)) {
+                  returnType = method.getReturnType();
+                  if (returnType != Object.class) {
+                     break;
                   }
-              }
-              if (returnType != null) {
-                  return returnType;
-              }
-          }
+               }
+            }
+            if (returnType != null) {
+               return returnType;
+            }
+         }
       }
 
       throw new IllegalStateException(Messages.MESSAGES.couldNotFindTypeForBean(name));
@@ -495,7 +502,8 @@ public class SpringBeanProcessor implements BeanFactoryPostProcessor, SmartAppli
 
    /**
     * Register all of the resources into RESTEasy only when Spring finishes it's
-    * life-cycle and the spring singleton bean creation is completed
+    * life-cycle and the spring singleton bean creation is completed.
+    * @param event application event
     */
    @Override
    public void onApplicationEvent(ApplicationEvent event)
