@@ -28,6 +28,7 @@ import javax.ws.rs.core.HttpHeaders;
 import javax.ws.rs.core.Response;
 import javax.ws.rs.core.UriInfo;
 
+import org.jboss.logging.Logger;
 import org.jboss.resteasy.annotations.security.doseta.After;
 import org.jboss.resteasy.annotations.security.doseta.Signed;
 import org.jboss.resteasy.annotations.security.doseta.Verify;
@@ -59,6 +60,7 @@ import org.junit.Test;
  */
 public class SigningTest
 {
+   private static final Logger LOG = Logger.getLogger(SigningTest.class);
    private static NettyJaxrsServer server;
    private static ResteasyDeployment deployment;
    public static KeyPair keys;
@@ -85,10 +87,11 @@ public class SigningTest
    }
 
    @Test
-   public void testMe() throws Exception
+   public void testMe()
    {
       URL url = Thread.currentThread().getContextClassLoader().getResource("dns/zones");
-      System.out.println(url.getFile());
+      Assert.assertTrue("'zones' string not in " + url.getFile(), url.getFile().contains("zones"));
+      Assert.assertTrue("'dns' string not in " + url.getFile(), url.getFile().contains("dns"));
    }
 
    @BeforeClass
@@ -131,23 +134,23 @@ public class SigningTest
    }
 
    @Path("/signed")
-   public static interface SigningProxy
+   public interface SigningProxy
    {
       @GET
       @Verify
       @Produces("text/plain")
       @Path("bad-signature")
-      public String bad();
+      String bad();
 
       @GET
       @Verify
       @Produces("text/plain")
-      public String hello();
+      String hello();
 
       @POST
       @Consumes("text/plain")
       @Signed(selector = "test", domain = "samplezone.org")
-      public void postSimple(String input);
+      void postSimple(String input);
    }
 
 
@@ -161,7 +164,7 @@ public class SigningTest
                                    @HeaderParam(DKIMSignature.DKIM_SIGNATURE)  DKIMSignature signature)
       {
          Assert.assertNotNull(signature);
-         System.out.println("Signature: " + signature);
+         LOG.info("Signature: " + signature);
          Verification verification = new Verification(keys.getPublic());
          verification.setBodyHashRequired(false);
          verification.getRequiredAttributes().put("method", "GET");
@@ -278,7 +281,7 @@ public class SigningTest
 
       @GET
       @Signed(selector = "test", domain = "samplezone.org",
-              timestamped = true)
+            timestamped = true)
       @Produces("text/plain")
       @Path("stamped")
       public String getStamp()
@@ -288,7 +291,7 @@ public class SigningTest
 
       @GET
       @Signed(selector = "test", domain = "samplezone.org",
-              expires = @After(seconds = 1))
+            expires = @After(seconds = 1))
       @Produces("text/plain")
       @Path("expires-short")
       public String getExpiresShort()
@@ -298,7 +301,7 @@ public class SigningTest
 
       @GET
       @Signed(selector = "test", domain = "samplezone.org",
-              expires = @After(minutes = 1))
+            expires = @After(minutes = 1))
       @Produces("text/plain")
       @Path("expires-minute")
       public String getExpiresMinute()
@@ -308,7 +311,7 @@ public class SigningTest
 
       @GET
       @Signed(selector = "test", domain = "samplezone.org",
-              expires = @After(hours = 1))
+            expires = @After(hours = 1))
       @Produces("text/plain")
       @Path("expires-hour")
       public String getExpiresHour()
@@ -318,7 +321,7 @@ public class SigningTest
 
       @GET
       @Signed(selector = "test", domain = "samplezone.org",
-              expires = @After(days = 1))
+            expires = @After(days = 1))
       @Produces("text/plain")
       @Path("expires-day")
       public String getExpiresDay()
@@ -328,7 +331,7 @@ public class SigningTest
 
       @GET
       @Signed(selector = "test", domain = "samplezone.org",
-              expires = @After(months = 1))
+            expires = @After(months = 1))
       @Produces("text/plain")
       @Path("expires-month")
       public String getExpiresMonth()
@@ -338,7 +341,7 @@ public class SigningTest
 
       @GET
       @Signed(selector = "test", domain = "samplezone.org",
-              expires = @After(years = 1))
+            expires = @After(years = 1))
       @Produces("text/plain")
       @Path("expires-year")
       public String getExpiresYear()
@@ -390,7 +393,7 @@ public class SigningTest
       });
       Assert.assertEquals("hello world", marshalledEntity.getEntity());
       String signatureHeader = response.getHeaderString(DKIMSignature.DKIM_SIGNATURE);
-      System.out.println(DKIMSignature.DKIM_SIGNATURE + ":  " + signatureHeader);
+      LOG.info(DKIMSignature.DKIM_SIGNATURE + ":  " + signatureHeader);
 
       Assert.assertNotNull(signatureHeader);
 
@@ -425,7 +428,7 @@ public class SigningTest
       contentSignature.setAttribute("code", "hello");
       contentSignature.setPrivateKey(keys.getPrivate());
       Response response = target.request().header(DKIMSignature.DKIM_SIGNATURE, contentSignature)
-              .post(Entity.text("hello world"));
+            .post(Entity.text("hello world"));
       Assert.assertEquals(204, response.getStatus());
       response.close();
 
@@ -442,7 +445,7 @@ public class SigningTest
       contentSignature.setSelector("test");
       contentSignature.setDomain("samplezone.org");
       Response response = target.request().header(DKIMSignature.DKIM_SIGNATURE, contentSignature)
-              .post(Entity.text("hello world"));
+            .post(Entity.text("hello world"));
       Assert.assertEquals(204, response.getStatus());
       response.close();
    }
@@ -457,7 +460,7 @@ public class SigningTest
       contentSignature.setDomain("samplezone.org");
       contentSignature.setPrivateKey(badKey);
       Response response = target.request().header(DKIMSignature.DKIM_SIGNATURE, contentSignature)
-              .post(Entity.text("hello world"));
+            .post(Entity.text("hello world"));
       Assert.assertEquals(401, response.getStatus());
       response.close();
    }
@@ -481,7 +484,7 @@ public class SigningTest
       signature.setDomain("samplezone.org");
       signature.sign(new HashMap(), "hello world".getBytes(), keys.getPrivate());
       String sig = signature.toString();
-      System.out.println(DKIMSignature.DKIM_SIGNATURE + ": " + sig);
+      LOG.info(DKIMSignature.DKIM_SIGNATURE + ": " + sig);
       signature = new DKIMSignature(sig);
 
    }
@@ -500,7 +503,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       try
       {
@@ -529,7 +532,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       Thread.sleep(1500);
       try
@@ -540,7 +543,7 @@ public class SigningTest
       catch (ProcessingException pe)
       {
          UnauthorizedSignatureException e = (UnauthorizedSignatureException)pe.getCause();
-         System.out.println("here");
+         LOG.info("here");
 //         Assert.assertEquals("Failed to verify signatures:\r\n Signature is stale", e.getMessage());
          Assert.assertTrue(e.getMessage().indexOf("Failed to verify signatures:\r\n") >= 0);
          Assert.assertTrue(e.getMessage().indexOf("Signature is stale") >= 0);
@@ -562,7 +565,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       String output = response.readEntity(String.class);
       response.close();
@@ -580,7 +583,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       String output = response.readEntity(String.class);
       response.close();
@@ -598,7 +601,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       String output = response.readEntity(String.class);
       response.close();
@@ -616,7 +619,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       String output = response.readEntity(String.class);
       response.close();
@@ -634,7 +637,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       String output = response.readEntity(String.class);
       response.close();
@@ -652,7 +655,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       Thread.sleep(1500);
       try
@@ -688,7 +691,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertNotNull(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       try
@@ -699,7 +702,7 @@ public class SigningTest
       catch (ProcessingException pe)
       {
          UnauthorizedSignatureException e = (UnauthorizedSignatureException)pe.getCause();
-         System.out.println("*************" + e.getMessage());
+         LOG.info("*************" + e.getMessage());
 //         Assert.assertEquals("Failed to verify signatures:\r\n Failed to verify signature.", e.getMessage());
          Assert.assertTrue(e.getMessage().indexOf("Failed to verify signatures:\r\n") >= 0);
          Assert.assertTrue(e.getMessage().indexOf("Failed to verify signature.") >= 0);
@@ -721,7 +724,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertNotNull(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       String output = response.readEntity(String.class);
@@ -741,7 +744,7 @@ public class SigningTest
       Invocation.Builder request = target.request();
       request.property(Verifier.class.getName(), verifier);
       Response response = request.get();
-      System.out.println(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
+      LOG.info(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertNotNull(response.getHeaderString(DKIMSignature.DKIM_SIGNATURE));
       Assert.assertEquals(200, response.getStatus());
       String output = response.readEntity(String.class);
@@ -759,7 +762,7 @@ public class SigningTest
       Assert.assertEquals(200, response.getStatus());
       String signatureHeader = response.getHeaderString(DKIMSignature.DKIM_SIGNATURE);
       Assert.assertNotNull(signatureHeader);
-      System.out.println(DKIMSignature.DKIM_SIGNATURE + ":  " + signatureHeader);
+      LOG.info(DKIMSignature.DKIM_SIGNATURE + ":  " + signatureHeader);
 
       DKIMSignature contentSignature = new DKIMSignature(signatureHeader);
 
@@ -787,7 +790,7 @@ public class SigningTest
       Assert.assertEquals(200, response.getStatus());
       String signatureHeader = response.getHeaderString(DKIMSignature.DKIM_SIGNATURE);
       Assert.assertNotNull(signatureHeader);
-      System.out.println(DKIMSignature.DKIM_SIGNATURE + ":  " + signatureHeader);
+      LOG.info(DKIMSignature.DKIM_SIGNATURE + ":  " + signatureHeader);
 
       DKIMSignature contentSignature = new DKIMSignature(signatureHeader);
 
@@ -833,7 +836,7 @@ public class SigningTest
       }
       catch (ResponseProcessingException e)
       {
-         System.out.println("*** cause ***: " + e.getCause().getClass().getName());
+         LOG.error("*** cause ***: " + e.getCause().getClass().getName());
          //Assert.assertTrue(e.getCause() instanceof UnauthorizedSignatureException);
       }
    }
