@@ -9,10 +9,10 @@ import org.jboss.resteasy.spi.interception.PostProcessInterceptor;
 @Provider
 @ServerInterceptor
 public class AsyncPostProcessingInterceptor implements PostProcessInterceptor {
-    public static boolean called;
+   public static volatile boolean called;
 
-    @Override
-    public void postProcess(ServerResponse response) {
-        called = true;
-    }
+   @Override
+   public void postProcess(ServerResponse response) {
+      called = true;
+   }
 }
