@@ -10,12 +10,12 @@ import java.util.List;
 @Provider
 @ApplicationPath("/")
 public class ApplicationInjection extends Application {
-    public static List<ApplicationInjection> instances = new ArrayList<>();
+   public static volatile List<ApplicationInjection> instances = new ArrayList<>();
 
-    @Context
-    public Application app;
+   @Context
+   public Application app;
 
-    public ApplicationInjection() {
-        instances.add(this);
-    }
+   public ApplicationInjection() {
+      instances.add(this);
+   }
 }
