@@ -1,5 +1,7 @@
 package org.jboss.resteasy.test.cdi.validation.resource;
 
+import org.jboss.logging.Logger;
+
 import javax.enterprise.context.RequestScoped;
 import javax.ws.rs.container.AsyncResponse;
 import javax.ws.rs.core.Response;
@@ -7,15 +9,17 @@ import javax.ws.rs.core.Response;
 @RequestScoped
 public class AsyncSubResourceImpl implements AsyncSubResource
 {
+
+   private static final Logger LOG = Logger.getLogger(AsyncSubResourceImpl.class);
    public AsyncSubResourceImpl()
    {
-      System.out.println("creating AsyncSubResourceImpl");
+      LOG.info("creating AsyncSubResourceImpl");
    }
 
    @Override
    public void getAll(AsyncResponse asyncResponse, QueryBeanParamImpl beanParam)
    {
-      System.out.println("sub#getAll: beanParam#getParam valid? " + beanParam.getParam());
+      LOG.info("sub#getAll: beanParam#getParam valid? " + beanParam.getParam());
       asyncResponse.resume(Response.ok().build());
    }
 }
