@@ -1,5 +1,8 @@
 package org.jboss.resteasy.test.core.basic.resource;
 
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
+
 import java.io.IOException;
 
 import javax.ws.rs.client.ClientRequestContext;
@@ -9,11 +12,13 @@ import javax.ws.rs.ext.Provider;
 
 @Provider
 public class NullHeaderFilter implements ClientRequestFilter {
-   
+
+   private static final Logger LOG = LogManager.getLogger(NullHeaderFilter.class);
+
    @Override
    public void filter(ClientRequestContext requestContext) throws IOException {
       MultivaluedMap<String, Object> headers = requestContext.getHeaders();
       headers.add("X-Client-Header", null);
-      System.out.println("added X-Client-Header");
+      LOG.info("added X-Client-Header");
    }
 }
