@@ -36,6 +36,8 @@
 
 package Acme;
 
+import org.jboss.logging.Logger;
+
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
@@ -85,6 +87,7 @@ import java.util.StringTokenizer;
 @Deprecated
 public class Utils
 {
+   private static final Logger LOG = Logger.getLogger(Utils.class);
    // / Returns a date string formatted in Unix ls style - if it's within
    // six months of now, Mmm dd hh:ss, else Mmm dd yyyy.
    static final SimpleDateFormat shortfmt = new SimpleDateFormat("MMM dd HH:mm");
@@ -160,7 +163,7 @@ public class Utils
    }
 
    public static Map parsePostData(long len, InputStream is, String encoding, String[] cachedStream)
-           throws IOException
+         throws IOException
    {
       // TODO: handle parsing data over 2 GB
       if (len > Integer.MAX_VALUE)
@@ -187,7 +190,7 @@ public class Utils
     * @param s   encoded string
     * @param enc source encoding
     * @return decoded string or original if no decoding required
-    * @throws UnsupportedEncodingException
+    * @throws UnsupportedEncodingException if the named charset is not supported
     */
    public static String decode(String s, String enc) throws UnsupportedEncodingException
    {
@@ -501,8 +504,8 @@ public class Utils
                ++p;
                for (i = string.length(); i >= s; --i)
                   if (match(pattern.substring(p), string.substring(i))) /*
-																														 * not quite right
-																														 */
+                                                                                           * not quite right
+                                                                                           */
                      return true;
                break;
             }
@@ -657,13 +660,13 @@ public class Utils
    }
 
    /*
-    public static Object[] copyOf(Object[] original, int from, int newLength) {
-       newLength = Math.min(original.length - from, newLength);
-       Object[] copy = new Object[newLength];
-       System.arraycopy(original, from, copy, 0, newLength);
-       return copy;
-    }
-     */
+   public static Object[] copyOf(Object[] original, int from, int newLength) {
+      newLength = Math.min(original.length - from, newLength);
+      Object[] copy = new Object[newLength];
+      System.arraycopy(original, from, copy, 0, newLength);
+      return copy;
+   }
+    */
    public static String canonicalizePath(String path)
    {
       if (path == null || path.length() == 0)
@@ -783,18 +786,17 @@ public class Utils
    }
 
    protected final static char BASE64ARRAY[] = {'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N',
-           'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i',
-           'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', '0', '1', '2', '3',
-           '4', '5', '6', '7', '8', '9', '+', '/'};
+      'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i',
+      'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', '0', '1', '2', '3',
+      '4', '5', '6', '7', '8', '9', '+', '/'};
 
    /**
     * base 64 encoding, string converted to bytes using specified encoding
     *
-    * @param String <val>_s</val> original string to encode
-    * @param String encoding, can be null, then iso-8859-1 used
+    * @param _s  original string to encode
+    * @param _enc String encoding, can be null, then iso-8859-1 used
     * @return String result of encoding as iso-8859-1 string<br>
     *         return null in case of invalid encoding or original string null
-    * @throws no exceptions
     */
    public final static String base64Encode(String _s, String _enc)
    {
@@ -808,7 +810,7 @@ public class Utils
       }
       catch (Exception e)
       {
-         e.printStackTrace();
+         LOG.error(e.getMessage(), e);
       }
       return null;
    }
@@ -816,11 +818,9 @@ public class Utils
    /**
     * base 64 encoding, array of bytes converted to bytes using specified encoding
     *
-    * @param String <val>_s</val> original string to encode
-    * @param String encoding, can be null, then iso-8859-1 used
-    * @return String result of encoding as iso-8859-1 string<br>
-    * @throws <code>NullPointerException</code>
-    *          if input parameter is null
+    * @param _bytes original bytes to encode
+    * @return String result of encoding as iso-8859-1 string
+    * @throws NullPointerException if input parameter is null
     */
    public final static String base64Encode(byte[] _bytes)
    {
@@ -874,31 +874,31 @@ public class Utils
     * Translates a Base64 value to either its 6-bit reconstruction value or a negative number indicating some other meaning.
     */
    protected final static byte[] DECODABET = {-9, -9, -9, -9, -9, -9, -9, -9, -9, // Decimal 0 - 8
-           -5, -5, // Whitespace: Tab and Linefeed
-           -9, -9, // Decimal 11 - 12
-           -5, // Whitespace: Carriage Return
-           -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, // Decimal 14 -
-           // 26
-           -9, -9, -9, -9, -9, // Decimal 27 - 31
-           -5, // Whitespace: Space
-           -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, // Decimal 33 - 42
-           62, // Plus sign at decimal 43
-           -9, -9, -9, // Decimal 44 - 46
-           63, // Slash at decimal 47
-           52, 53, 54, 55, 56, 57, 58, 59, 60, 61, // Numbers zero through nine
-           -9, -9, -9, // Decimal 58 - 60
-           -1, // Equals sign at decimal 61
-           -9, -9, -9, // Decimal 62 - 64
-           0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, // Letters 'A'
-           // through 'N'
-           14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, // Letters 'O'
-           // through 'Z'
-           -9, -9, -9, -9, -9, -9, // Decimal 91 - 96
-           26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, // Letters 'a'
-           // through 'm'
-           39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, // Letters 'n'
-           // through 'z'
-           -9, -9, -9, -9 // Decimal 123 - 126
+      -5, -5, // Whitespace: Tab and Linefeed
+      -9, -9, // Decimal 11 - 12
+      -5, // Whitespace: Carriage Return
+      -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, // Decimal 14 -
+      // 26
+      -9, -9, -9, -9, -9, // Decimal 27 - 31
+      -5, // Whitespace: Space
+      -9, -9, -9, -9, -9, -9, -9, -9, -9, -9, // Decimal 33 - 42
+      62, // Plus sign at decimal 43
+      -9, -9, -9, // Decimal 44 - 46
+      63, // Slash at decimal 47
+      52, 53, 54, 55, 56, 57, 58, 59, 60, 61, // Numbers zero through nine
+      -9, -9, -9, // Decimal 58 - 60
+      -1, // Equals sign at decimal 61
+      -9, -9, -9, // Decimal 62 - 64
+      0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, // Letters 'A'
+      // through 'N'
+      14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, // Letters 'O'
+      // through 'Z'
+      -9, -9, -9, -9, -9, -9, // Decimal 91 - 96
+      26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, // Letters 'a'
+      // through 'm'
+      39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, // Letters 'n'
+      // through 'z'
+      -9, -9, -9, -9 // Decimal 123 - 126
    };
 
    protected final static byte WHITE_SPACE_ENC = -5; // Indicates white space
@@ -917,8 +917,8 @@ public class Utils
    /**
     * base 64 decoding
     *
-    * @param encoded  string
-    * @param encoding used to get string bytes
+    * @param _s string
+    * @param _enc used to get string bytes
     * @return result of encoding, or null if encoding invalid or string null, or string is invalid base 64 encoding
     */
    public final static String base64Decode(String _s, String _enc)
@@ -996,9 +996,9 @@ public class Utils
             // | ( ( DECODABET[ source[ srcOffset + 2 ] ] << 24 ) >>> 18 )
             // | ( ( DECODABET[ source[ srcOffset + 3 ] ] << 24 ) >>> 24 );
             int outBuff = ((DECODABET[source[srcOffset]] & 0xFF) << 18)
-                    | ((DECODABET[source[srcOffset + 1]] & 0xFF) << 12)
-                    | ((DECODABET[source[srcOffset + 2]] & 0xFF) << 6)
-                    | ((DECODABET[source[srcOffset + 3]] & 0xFF));
+               | ((DECODABET[source[srcOffset + 1]] & 0xFF) << 12)
+               | ((DECODABET[source[srcOffset + 2]] & 0xFF) << 6)
+               | ((DECODABET[source[srcOffset + 3]] & 0xFF));
 
             destination[destOffset] = (byte) (outBuff >> 16);
             destination[destOffset + 1] = (byte) (outBuff >> 8);
@@ -1008,10 +1008,10 @@ public class Utils
          }
          catch (Exception e)
          {
-            System.out.println("" + source[srcOffset] + ": " + (DECODABET[source[srcOffset]]));
-            System.out.println("" + source[srcOffset + 1] + ": " + (DECODABET[source[srcOffset + 1]]));
-            System.out.println("" + source[srcOffset + 2] + ": " + (DECODABET[source[srcOffset + 2]]));
-            System.out.println("" + source[srcOffset + 3] + ": " + (DECODABET[source[srcOffset + 3]]));
+            LOG.info("" + source[srcOffset] + ": " + (DECODABET[source[srcOffset]]));
+            LOG.info("" + source[srcOffset + 1] + ": " + (DECODABET[source[srcOffset + 1]]));
+            LOG.info("" + source[srcOffset + 2] + ": " + (DECODABET[source[srcOffset + 2]]));
+            LOG.info("" + source[srcOffset + 3] + ": " + (DECODABET[source[srcOffset + 3]]));
             return -1;
          } // e nd catch
       }
@@ -1063,7 +1063,7 @@ public class Utils
          } // end if: white space, equals sign or better
          else
          {
-            System.err.println("Bad Base64 input character at " + i + ": " + source[i] + "(decimal)");
+            LOG.error("Bad Base64 input character at " + i + ": " + source[i] + "(decimal)");
             return null;
          } // end else:
       } // each input character
@@ -1222,7 +1222,7 @@ public class Utils
    //
    // }
 
-   public static interface ThreadFactory
+   public interface ThreadFactory
    {
       Thread create(Runnable runnable);
    }
@@ -1248,7 +1248,8 @@ public class Utils
       /**
        * Creates a thread pool not queued with max number of threads defined in properties or DEF_MAX_POOLED_THREAD = 20
        *
-       * @param Properties where property THREADSINPOOL gives max threads Note if THREADSINPOOL not integers, or negative then DEF_MAX_POOLED_THREAD used
+       * @param properties where property THREADSINPOOL gives max threads Note if THREADSINPOOL not integers, or negative then DEF_MAX_POOLED_THREAD used
+       * @param threadfactory thread factory
        */
       public ThreadPool(Properties properties, ThreadFactory threadfactory)
       {
@@ -1270,7 +1271,7 @@ public class Utils
       /**
        * Assigns a new value for max threads
        *
-       * @param int new value of max threads, can't be less than 2, but can be 0 If current number threads exceed the value, then extra thread will be
+       * @param newSize new value of max threads, can't be less than 2, but can be 0 If current number threads exceed the value, then extra thread will be
        *            discarded gracefully
        */
       public void setMaxThreads(int newSize)
@@ -1292,7 +1293,7 @@ public class Utils
       /**
        * Takes a new task for execution by a threads in pool will wait until free threads if number of threads reached max
        *
-       * @param Runnable task for execution
+       * @param runnable task for execution
        */
       public void executeThread(Runnable runnable)
       {
@@ -1411,7 +1412,7 @@ public class Utils
                   {
                      if (t instanceof ThreadDeath)
                         throw (ThreadDeath) t;
-                     t.printStackTrace();
+                     LOG.error(t.getMessage(), t);
                   }
                   finally
                   {
@@ -1563,12 +1564,12 @@ public class Utils
    {
       try
       {
-         System.out.println(args[0]);
-         System.out.println(canonicalizePath(args[0]));
+         LOG.info(args[0]);
+         LOG.info(canonicalizePath(args[0]));
       }
       catch (Exception e)
       {
-         e.printStackTrace();
+         LOG.error(e.getMessage(), e);
       }
    }
 }
